% Auto-generated chapter 50 for nasai
% Hadiths in this chapter: 112

\hadithdefcmd{nasai}{5428}{أَخْبَرَنَا أَبُو عَبْدِ الرَّحْمَنِ، أَحْمَدُ بْنُ شُعَيْبٍ قَالَ أَنْبَأَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَبُو عَاصِمٍ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، قَالَ حَدَّثَنِي أَسِيدُ بْنُ أَبِي أَسِيدٍ، عَنْ مُعَاذِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ أَصَابَنَا طَشٌّ وَظُلْمَةٌ فَانْتَظَرْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم لِيُصَلِّيَ بِنَا ثُمَّ ذَكَرَ كَلاَمًا مَعْنَاهُ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِيُصَلِّيَ بِنَا فَقَالَ ‏"‏ قُلْ ‏"‏ ‏.‏ فَقُلْتُ مَا أَقُولُ قَالَ ‏"‏ ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ ‏\}‏ وَالْمُعَوِّذَتَيْنِ حِينَ تُمْسِي وَحِينَ تُصْبِحُ ثَلاَثًا يَكْفِيكَ كُلَّ شَىْءٍ ‏"‏ ‏.‏\hadithno{5428}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Mu'adh bin 'Abdullah that his father said:"It was raining and dark, and we were waiting for the Messenger of Allah [SAW] to lead us in prayer. Then the Messenger of Allah [SAW] came out to lead us in prayer and he said: 'Say.' I said: 'What should I say?' He said: 'Say: He is Allah, (the) One and Al-Mu'awwadhatain in the evening and in the morning, three times, and that will suffice you against everything}}
\hadithdefcmd{nasai}{5429}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي حَفْصُ بْنُ مَيْسَرَةَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ مُعَاذِ بْنِ عَبْدِ اللَّهِ بْنِ خُبَيْبٍ، عَنْ أَبِيهِ، قَالَ كُنْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي طَرِيقِ مَكَّةَ فَأَصَبْتُ خَلْوَةً مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَدَنَوْتُ مِنْهُ فَقَالَ ‏"‏ قُلْ ‏"‏ ‏.‏ فَقُلْتُ مَا أَقُولُ قَالَ ‏"‏ قُلْ ‏"‏ ‏.‏ قُلْتُ مَا أَقُولُ قَالَ ‏"‏ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ الْفَلَقِ ‏\}‏ ‏"‏ ‏.‏ حَتَّى خَتَمَهَا ثُمَّ قَالَ ‏"‏ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ النَّاسِ ‏\}‏ ‏"‏ ‏.‏ حَتَّى خَتَمَهَا ثُمَّ قَالَ ‏"‏ مَا تَعَوَّذَ النَّاسُ بِأَفْضَلَ مِنْهُمَا ‏"‏ ‏.‏\hadithno{5429}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Mu'adh bin 'Abdullah bin Khubaib that his father said:"I was with the Messenger of Allah [SAW] on the road to Makkah when I found myself alone with the Messenger of Allah [SAW]. I drew close to him and he said: 'Say.' I said: 'What should I say?' He said: 'Say.' I said: 'What should I say?' He said: 'Say: I seek refuge with (Allah) the Lord of the daybreak...' until he finished (the Surah), then he said: 'Say: I seek refuge with (Allah) the Lord of mankind...' until he finished it. Then he said: 'The people cannot seek refuge with Allah by means of anything better than these two}}
\hadithdefcmd{nasai}{5430}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَلِيٍّ، قَالَ حَدَّثَنِي الْقَعْنَبِيُّ، عَنْ عَبْدِ الْعَزِيزِ، عَنْ عَبْدِ اللَّهِ بْنِ سُلَيْمَانَ، عَنْ مُعَاذِ بْنِ عَبْدِ اللَّهِ بْنِ خُبَيْبٍ، عَنْ أَبِيهِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، قَالَ بَيْنَا أَنَا أَقُودُ، بِرَسُولِ اللَّهِ صلى الله عليه وسلم رَاحِلَتَهُ فِي غَزْوَةٍ إِذْ قَالَ ‏"‏ يَا عُقْبَةُ قُلْ ‏"‏ ‏.‏ فَاسْتَمَعْتُ ثُمَّ قَالَ ‏"‏ يَا عُقْبَةُ قُلْ ‏"‏ ‏.‏ فَاسْتَمَعْتُ فَقَالَهَا الثَّالِثَةَ فَقُلْتُ مَا أَقُولُ فَقَالَ ‏"‏ ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ ‏\}‏ ‏"‏ ‏.‏ فَقَرَأَ السُّورَةَ حَتَّى خَتَمَهَا ثُمَّ قَرَأَ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ الْفَلَقِ ‏\}‏ وَقَرَأْتُ مَعَهُ حَتَّى خَتَمَهَا ثُمَّ قَرَأَ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ النَّاسِ ‏\}‏ فَقَرَأْتُ مَعَهُ حَتَّى خَتَمَهَا ثُمَّ قَالَ ‏"‏ مَا تَعَوَّذَ بِمِثْلِهِنَّ أَحَدٌ ‏"‏ ‏.‏\hadithno{5430}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Uqbah bin 'Amir Al-Juhani said:"While I was leading the Messenger of Allah [SAW] on his mount on a military campaign, he said: 'O 'Uqbah, say!' I listened, then he said: 'O 'Uqbah, say!' I listened, then he said it a third time. I said: 'What should I say?' He said: 'Say: He is Allah, (the) One...' and he recited the Surah to the end. Then he recited: 'Say: I seek refuge with (Allah) the Lord of the daybreak...' and I recited it with him until the end. Then he recited: 'Say: I seek refuge with (Allah) the Lord of mankind...' and I recited it with him until the end. Then he said: 'No one ever sought refuge (with Allah) by means of anything like them}}
\hadithdefcmd{nasai}{5431}{أَخْبَرَنَا أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ، قَالَ حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ سُلَيْمَانَ الأَسْلَمِيُّ، عَنْ مُعَاذِ بْنِ عَبْدِ اللَّهِ بْنِ خُبَيْبٍ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قُلْ ‏"‏ ‏.‏ قُلْتُ وَمَا أَقُولُ قَالَ ‏"‏ ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ ‏\}‏ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ الْفَلَقِ ‏\}‏ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ النَّاسِ ‏\}‏ ‏"‏ ‏.‏ فَقَرَأَهُنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ لَمْ يَتَعَوَّذِ النَّاسُ بِمِثْلِهِنَّ أَوْ لاَ يَتَعَوَّذُ النَّاسُ بِمِثْلِهِنَّ ‏"‏ ‏.‏\hadithno{5431}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Uqbah bin 'Amir Al-Juhani said:"The Messenger of Allah [SAW] said to me: 'Say.' I said: 'What should I say?' He said: 'Say: He is Allah (the) One,' 'Say: I seek refuge with (Allah) the Lord of the daybreak,' 'Say: I seek refuge with (Allah) the Lord of mankind.' The Messenger of Allah [SAW] recited them, then he said: 'The people have never recited anything like them, or the people have never sought refuge (with Allah) by means of anything like them}}
\hadithdefcmd{nasai}{5432}{أَخْبَرَنَا مَحْمُودُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا الْوَلِيدُ، قَالَ حَدَّثَنَا أَبُو عَمْرٍو، عَنْ يَحْيَى، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ، أَخْبَرَنِي أَبُو عَبْدِ اللَّهِ، أَنَّ ابْنَ عَابِسٍ الْجُهَنِيَّ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهُ ‏"‏ يَا ابْنَ عَابِسٍ أَلاَ أَدُلُّكَ - أَوْ قَالَ أَلاَ أُخْبِرُكَ - بِأَفْضَلِ مَا يَتَعَوَّذُ بِهِ الْمُتَعَوِّذُونَ ‏"‏ ‏.‏ قَالَ بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ الْفَلَقِ ‏\}‏ وَ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ النَّاسِ ‏\}‏ هَاتَيْنِ السُّورَتَيْنِ ‏"‏ ‏.‏\hadithno{5432}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu 'Abdullah narrated that Ibn 'Abis Al-Juhani told him that:The Messenger of Allah [SAW] said to him: "O Ibn 'Abis, shall I not tell you of the best thing with which those who seek refuge with Allah may do so?" He said: "Yes, O Messenger of Allah." He said: "Say: I seek refuge with (Allah) the Lord of the daybreak.", "Say: I seek refuge with (Allah) the Lord of mankind." - these two Surahs}}
\hadithdefcmd{nasai}{5433}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَقِيَّةُ، قَالَ حَدَّثَنَا بَحِيرُ بْنُ سَعْدٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ أُهْدِيَتْ لِلنَّبِيِّ صلى الله عليه وسلم بَغْلَةٌ شَهْبَاءُ فَرَكِبَهَا وَأَخَذَ عُقْبَةُ يَقُودُهَا بِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِعُقْبَةَ ‏"‏ اقْرَأْ ‏"‏ ‏.‏ قَالَ وَمَا أَقْرَأُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ اقْرَأْ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ الْفَلَقِ * مِنْ شَرِّ مَا خَلَقَ ‏\}‏ ‏"‏ ‏.‏ فَأَعَادَهَا عَلَىَّ حَتَّى قَرَأْتُهَا فَعَرَفَ أَنِّي لَمْ أَفْرَحْ بِهَا جِدًّا قَالَ ‏"‏ لَعَلَّكَ تَهَاوَنْتَ بِهَا ‏"‏ ‏.‏ فَمَا قُمْتُ يَعْنِي بِمِثْلِهَا ‏.‏\hadithno{5433}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Uqbah bin 'Amir said:"The Prophet [SAW] was given a gray mule which he rode, and 'Uqbah led it. The Messenger of Allah [SAW] said to 'Uqbah: 'Recite.' He said: 'What should I recite, O Messenger of Allah?' He said: 'Recite: 'Say: I seek refuge with (Allah) the Lord of the daybreak, from the evil of what He has created.' And he repeated it until I had learned it}}
\hadithdefcmd{nasai}{5434}{أَخْبَرَنَا مُوسَى بْنُ حِزَامٍ التِّرْمِذِيُّ، قَالَ أَنْبَأَنَا أَبُو أُسَامَةَ، عَنْ سُفْيَانَ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِيهِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّهُ سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْمُعَوِّذَتَيْنِ ‏.‏ قَالَ عُقْبَةُ فَأَمَّنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِهِمَا فِي صَلاَةِ الْغَدَاةِ ‏.‏\hadithno{5434}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Uqbah bin 'Amir that :He asked the Messenger of Allah [SAW] about Al-Mu'awwidhatain. 'Uqbah said: "The Messenger of Allah [SAW] recited them when he led us in Salah Al-Ghadah (As-Subh)}}
\hadithdefcmd{nasai}{5435}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا مُعَاوِيَةُ، عَنِ الْعَلاَءِ بْنِ الْحَارِثِ، عَنْ مَكْحُولٍ، عَنْ عُقْبَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَرَأَ بِهِمَا فِي صَلاَةِ الصُّبْحِ ‏.‏\hadithno{5435}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Uqbah that:The Messenger of Allah [SAW] recited them in the Subh prayer}}
\hadithdefcmd{nasai}{5436}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرٍو، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي مُعَاوِيَةُ بْنُ صَالِحٍ، عَنِ ابْنِ الْحَارِثِ، - وَهُوَ الْعَلاَءُ - عَنِ الْقَاسِمِ، مَوْلَى مُعَاوِيَةَ عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ كُنْتُ أَقُودُ بِرَسُولِ اللَّهِ صلى الله عليه وسلم فِي السَّفَرِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا عُقْبَةُ أَلاَ أُعَلِّمُكَ خَيْرَ سُورَتَيْنِ قُرِئَتَا ‏"‏ ‏.‏ فَعَلَّمَنِي ‏\{‏ قُلْ أَعُوذُ بِرَبِّ الْفَلَقِ ‏\}‏ وَ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ النَّاسِ ‏\}‏ فَلَمْ يَرَنِي سُرِرْتُ بِهِمَا جِدًّا فَلَمَّا نَزَلَ لِصَلاَةِ الصُّبْحِ صَلَّى بِهِمَا صَلاَةَ الصُّبْحِ لِلنَّاسِ فَلَمَّا فَرَغَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الصَّلاَةِ الْتَفَتَ إِلَىَّ فَقَالَ ‏"‏ يَا عُقْبَةُ كَيْفَ رَأَيْتَ ‏"‏ ‏.‏\hadithno{5436}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Uqbah bin 'Amir said:"I was leading the Messenger of Allah [SAW] (on his mount) on a journey, and the Messenger of Allah [SAW] said: 'O 'Uqbah, shall I not teach you the best two Surahs that can be recited?' And he taught me: 'Say: I seek refuge with (Allah) the Lord of the daybreak.' And 'Say: I seek refuge with (Allah) the Lord of mankind...' He thought that I did not seem too overjoyed with them, so when he stopped to pray Subh, he recited them when he led the people in the Subh prayer. When the Messenger of Allah [SAW] finished praying, he turned to me and said: 'O 'Uqbah, what do you think?}}
\hadithdefcmd{nasai}{5437}{أَخْبَرَنِي مَحْمُودُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا الْوَلِيدُ، قَالَ حَدَّثَنِي ابْنُ جَابِرٍ، عَنِ الْقَاسِمِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ بَيْنَا أَقُودُ بِرَسُولِ اللَّهِ صلى الله عليه وسلم فِي نَقَبٍ مِنْ تِلْكَ النِّقَابِ إِذْ قَالَ ‏"‏ أَلاَ تَرْكَبُ يَا عُقْبَةُ ‏"‏ ‏.‏ فَأَجْلَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ أَرْكَبَ مَرْكَبَ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ أَلاَ تَرْكَبُ يَا عُقْبَةُ ‏"‏ ‏.‏ فَأَشْفَقْتُ أَنْ يَكُونَ مَعْصِيَةً فَنَزَلَ وَرَكِبْتُ هُنَيْهَةً وَنَزَلْتُ وَرَكِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ أَلاَ أُعَلِّمُكَ سُورَتَيْنِ مِنْ خَيْرِ سُورَتَيْنِ قَرَأَ بِهِمَا النَّاسُ ‏"‏ ‏.‏ فَأَقْرَأَنِي ‏\{‏ قُلْ أَعُوذُ بِرَبِّ الْفَلَقِ ‏\}‏ وَ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ النَّاسِ ‏\}‏ فَأُقِيمَتِ الصَّلاَةُ فَتَقَدَّمَ فَقَرَأَ بِهِمَا ثُمَّ مَرَّ بِي فَقَالَ ‏"‏ كَيْفَ رَأَيْتَ يَا عُقْبَةُ بْنَ عَامِرٍ اقْرَأْ بِهِمَا كُلَّمَا نِمْتَ وَقُمْتَ ‏"‏ ‏.‏\hadithno{5437}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Uqbah bin 'Amir said:"While I was leading the Messenger of Allah [SAW] (on his mount) in one of these mountain passes, he said: 'Why don't you ride, O 'Uqbah?' I had too much respect for the Messenger of Allah [SAW] to ride the mount of the Messenger of Allah [SAW]. Then he said: 'Why don't you ride, O 'Uqbah?' I was worried that I might be disobeying him, so he got off, and I rode for a little while, then I got off and the Messenger of Allah [SAW] rode. Then he said: 'Shall I not teach you two of the best Surahs that the people recite?' And he taught me: 'Say: I seek refuge with (Allah) the Lord of the daybreak,' and 'Say: I seek refuge with (Allah) the Lord of mankind." Then the Iqamah was said and he went forward and recited them. Then he passed by me and said: 'What do you think, O 'Uqbah bin 'Amir? Recite them every time you go to sleep and get up}}
\hadithdefcmd{nasai}{5438}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ كُنْتُ أَمْشِي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ يَا عُقْبَةُ قُلْ ‏"‏ ‏.‏ فَقُلْتُ مَاذَا أَقُولُ يَا رَسُولَ اللَّهِ فَسَكَتَ عَنِّي ثُمَّ قَالَ ‏"‏ يَا عُقْبَةُ قُلْ ‏"‏ ‏.‏ قُلْتُ مَاذَا أَقُولُ يَا رَسُولَ اللَّهِ فَسَكَتَ عَنِّي فَقُلْتُ اللَّهُمَّ ارْدُدْهُ عَلَىَّ فَقَالَ ‏"‏ يَا عُقْبَةُ قُلْ ‏"‏ ‏.‏ قُلْتُ مَاذَا أَقُولُ يَا رَسُولَ اللَّهِ فَقَالَ ‏"‏ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ الْفَلَقِ ‏\}‏ فَقَرَأْتُهَا حَتَّى أَتَيْتُ عَلَى آخِرِهَا ثُمَّ قَالَ ‏"‏ قُلْ ‏"‏ ‏.‏ قُلْتُ مَاذَا أَقُولُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ النَّاسِ ‏\}‏ ‏"‏ ‏.‏ فَقَرَأْتُهَا حَتَّى أَتَيْتُ عَلَى آخِرِهَا ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَ ذَلِكَ ‏"‏ مَا سَأَلَ سَائِلٌ بِمِثْلِهِمَا وَلاَ اسْتَعَاذَ مُسْتَعِيذٌ بِمِثْلِهِمَا ‏"‏ ‏.‏\hadithno{5438}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Uqbah bin 'Amir said:"I was walking with the Messenger of Allah [SAW] and he said: "O 'Uqbah, say!' I said: 'What should I say, O Messenger of Allah?' He did not answer me, then h esaid: 'O 'Uqbah, say!' I said: 'What should I say, O Messenger of Allah?' But he did not answer me. I said: 'O Allah, make him answer me.' He said: 'O 'Uqbah, say!' I said: 'What should I say, O Messenger of Allah?' He said: 'Say: I seek refuge with (Allah) the Lord of the daybreak...' So I recited it until I came to the end. Then he said: 'Say,' and I said: 'What should I say, O Messenger of Allah?' He said: 'Say: I seek refuge with (Allah) the Lord of mankind...,' so I recited it until I came to the end. Then the Messenger of Allah [SAW] said: 'No one who asks has ever asked by means of anything like them, and no one who seeks refuge has ever sought refuge with anything like them}}
\hadithdefcmd{nasai}{5439}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي عِمْرَانَ، أَسْلَمَ عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ رَاكِبٌ فَوَضَعْتُ يَدِي عَلَى قَدَمِهِ فَقُلْتُ أَقْرِئْنِي سُورَةَ هُودٍ أَقْرِئْنِي سُورَةَ يُوسُفَ ‏.‏ فَقَالَ ‏"‏ لَنْ تَقْرَأَ شَيْئًا أَبْلَغَ عِنْدَ اللَّهِ عَزَّ وَجَلَّ مِنْ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ الْفَلَقِ ‏\}‏ ‏"‏ ‏.‏\hadithno{5439}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Uqbah bin 'Amir said:"I came to the Messenger of Allah [SAW] while he was riding, and I put my hand on his foot and said: 'Teach me Surah Hud, teach me Surah Yusuf. He said: 'You will never recite anything more precious before Allah, the Mighty and Sublime, than: 'Say: I seek refuge with (Allah) the Lord of the daybreak}}
\hadithdefcmd{nasai}{5440}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا قَيْسٌ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ أُنْزِلَ عَلَىَّ آيَاتٌ لَمْ يُرَ مِثْلُهُنَّ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ الْفَلَقِ ‏\}‏ إِلَى آخِرِ السُّورَةِ وَ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ النَّاسِ ‏\}‏ ‏"‏ ‏.‏ إِلَى آخِرِ السُّورَةِ ‏.‏\hadithno{5440}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Uqbah bin 'Amir that:The Prophet [SAW] said: "There have been revealed to me Verses the like of which has never been seen: 'Say: I seek refuge with (Allah) the Lord of the daybreak...' to the end of the Surah, and 'Say: I seek refuge with (Allah) the Lord of mankind...' to the end of the Surah}}
\hadithdefcmd{nasai}{5441}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنِي بَدَلٌ، قَالَ حَدَّثَنَا شَدَّادُ بْنُ سَعِيدٍ أَبُو طَلْحَةَ، قَالَ حَدَّثَنَا سَعِيدٌ الْجُرَيْرِيُّ، قَالَ حَدَّثَنَا أَبُو نَضْرَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْرَأْ يَا جَابِرُ ‏"‏ ‏.‏ قُلْتُ وَمَاذَا أَقْرَأُ بِأَبِي أَنْتَ وَأُمِّي يَا رَسُولَ اللَّهِ قَالَ ‏"‏ اقْرَأْ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ الْفَلَقِ ‏\}‏ وَ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ النَّاسِ ‏\}‏ ‏"‏ ‏.‏ فَقَرَأْتُهُمَا فَقَالَ ‏"‏ اقْرَأْ بِهِمَا وَلَنْ تَقْرَأَ بِمِثْلِهِمَا ‏"‏ ‏.‏\hadithno{5441}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"The Messenger of Allah [SAW] said to me: 'Recite, O Jabir!' I said: 'What should I recite, may my father and mother be ransomed for you, O Messenger of Allah?' He said: Recite: 'Say: I seek refuge with (Allah) the Lord of the daybreak...,' and: 'Say: I seek refuge with (Allah) the Lord of mankind...' So I recited them, and he said: 'Recite them, for you will never recite anything like them}}
\hadithdefcmd{nasai}{5442}{أَخْبَرَنَا يَزِيدُ بْنُ سِنَانٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنْ أَبِي سِنَانٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي الْهُذَيْلِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَتَعَوَّذُ مِنْ أَرْبَعٍ مِنْ عِلْمٍ لاَ يَنْفَعُ وَمِنْ قَلْبٍ لاَ يَخْشَعُ وَدُعَاءٍ لاَ يُسْمَعُ وَنَفْسٍ لاَ تَشْبَعُ ‏.‏\hadithno{5442}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin Amr that:The Prophet [SAW] used to seek refuge (with Allah) from four things: From knowledge that is of no benefit, from a heart that does not feel humble, from a supplication that is not heard, and a soul that is never satisfied}}
\hadithdefcmd{nasai}{5443}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عُبَيْدُ اللَّهِ، قَالَ حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَمُرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَتَعَوَّذُ مِنَ الْجُبْنِ وَالْبُخْلِ وَفِتْنَةِ الصَّدْرِ وَعَذَابِ الْقَبْرِ ‏.‏\hadithno{5443}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Umar that:The Prophet [SAW] used to seek refuge with Allah from cowardice, miserliness, the tribulation of the heart and the torment of the grave}}
\hadithdefcmd{nasai}{5444}{أَخْبَرَنَا الْحُسَيْنُ بْنُ إِسْحَاقَ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا سَعْدُ بْنُ أَوْسٍ، قَالَ حَدَّثَنِي بِلاَلُ بْنُ يَحْيَى، أَنَّ شُتَيْرَ بْنَ شَكَلٍ، أَخْبَرَهُ عَنْ أَبِيهِ، شَكَلِ بْنِ حُمَيْدٍ قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ يَا نَبِيَّ اللَّهِ عَلِّمْنِي تَعَوُّذًا أَتَعَوَّذُ بِهِ فَأَخَذَ بِيَدِي ثُمَّ قَالَ ‏ "‏ قُلْ أَعُوذُ بِكَ مِنْ شَرِّ سَمْعِي وَشَرِّ بَصَرِي وَشَرِّ لِسَانِي وَشَرِّ قَلْبِي وَشَرِّ مَنِيِّي ‏"‏ ‏.‏ قَالَ حَتَّى حَفِظْتُهَا قَالَ سَعْدٌ وَالْمَنِيُّ مَاؤُهُ ‏.‏\hadithno{5444}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Shakal bin Humaid said:"I came to the Prophet [SAW] and said: 'O Prophet of Allah, teach me words by means of which I may seek refuge with Allah.' He took me by the hand and said: 'Say: A'udhu bika min sharri sam'i, wa sharri basari, wa sharri lisani, wa sharri qalbi, wa sharri mani (I seek refuge with You from the evil of my hearing, the evil of my seeing, the evil of my tongue, the evil of my heart, and the evil of my sperm)}}
\hadithdefcmd{nasai}{5445}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، قَالَ سَمِعْتُ مُصْعَبَ بْنَ سَعْدٍ، عَنْ أَبِيهِ، قَالَ كَانَ يُعَلِّمُنَا خَمْسًا كَانَ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْعُو بِهِنَّ وَيَقُولُهُنَّ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْبُخْلِ وَأَعُوذُ بِكَ مِنَ الْجُبْنِ وَأَعُوذُ بِكَ أَنْ أُرَدَّ إِلَى أَرْذَلِ الْعُمُرِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الدُّنْيَا وَأَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ ‏"‏ ‏.‏\hadithno{5445}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Abudl-Malik bin 'Umair said:"I heard Mus'ab bin Sa'd (narrate) about his father: 'He used to tech us five things, which he said that the Messenger of Allah [SAW] used to recite in his supplication: 'Allahumma inni a'udhu bika minal-bukhli, wa a'udhu bika minal-jubni, wa a'udhu bika an uradda ila ardhalil-'umuri, wa a'udhu bika min fitnatid-dunya, wa a'udhu bika min 'adhabil-qabr (O Allah, I seek refuge in You from miserliness, and I seek refuge in You from cowardice, and I seek refuge in You from reaching the age of senility, and I seek refuge in You from the trials of this world, and I seek refuge in You from the torment of the grave)}}
\hadithdefcmd{nasai}{5446}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الْعَزِيزِ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ زَكَرِيَّا، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنِ ابْنِ مَسْعُودٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَتَعَوَّذُ مِنْ خَمْسٍ مِنَ الْبُخْلِ وَالْجُبْنِ وَسُوءِ الْعُمُرِ وَفِتْنَةِ الصَّدْرِ وَعَذَابِ الْقَبْرِ ‏.‏\hadithno{5446}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn Mas'ud said:"The Prophet [SAW] used to seek refuge (with Allah) from five things: From miserliness, cowardice, reaching the age of second childhood, the tribulation of the heart and the torment of the grave}}
\hadithdefcmd{nasai}{5447}{أَخْبَرَنَا يَحْيَى بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ عَمْرِو بْنِ مَيْمُونٍ الأَوْدِيِّ، قَالَ كَانَ سَعْدٌ يُعَلِّمُ بَنِيهِ هَؤُلاَءِ الْكَلِمَاتِ كَمَا يُعَلِّمُ الْمُعَلِّمُ الْغِلْمَانَ وَيَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَتَعَوَّذُ بِهِنَّ دُبُرَ الصَّلاَةِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْبُخْلِ وَأَعُوذُ بِكَ مِنَ الْجُبْنِ وَأَعُوذُ بِكَ أَنْ أُرَدَّ إِلَى أَرْذَلِ الْعُمُرِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الدُّنْيَا وَأَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ ‏"‏ ‏.‏ فَحَدَّثْتُ بِهَا مُصْعَبًا فَصَدَّقَهُ ‏.‏\hadithno{5447}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Amr bin Maimun Al-Awdi said:"Sa'd used to teach his children these words as a teacher teaches his students, and he said that the Messenger of Allah [SAW] used to seek refuge by means of them at the end of every prayer: 'Allahumma inni a'udhu bika minal-bukhli, wa a'udhu bika minal-jubni, wa a'udhu bika an uradda ila ardhalil-'umuri, wa a'udhu bika min fitnatid-dunya, wa a'udhu bika min 'adhabil-qabr (O Allah, I seek refuge with You from miserliness, and I seek refuge in You from cowardice, and I seek refuge in You from reaching the age of senility, and I seek refuge in You from the trials of this world, and I seek refuge in You from the torment of the grave.) So I narrated that to Mus'ab and he said that he told the truth}}
\hadithdefcmd{nasai}{5448}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ مُعَاذِ بْنِ هِشَامٍ، قَالَ حَدَّثَنَا أَبِي، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْعَجْزِ وَالْكَسَلِ وَالْبُخْلِ وَالْهَرَمِ وَعَذَابِ الْقَبْرِ وَفِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏ ‏.‏\hadithno{5448}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas that:The Messenger of Allah [SAW] used to say: "Allahumma inni a'udhu bika minal-'ajzi, wal-kasali, wal-bukhli, wal-harami, 'adhabil-qabr wa fitnatil-mahya wal-mamat (O Allah, I seek refuge in You from incapacity and laziness, and miserliness and old age, and the torment of the grave, and the trials of life and death)}}
\hadithdefcmd{nasai}{5449}{أَخْبَرَنَا عَلِيُّ بْنُ الْمُنْذِرِ، عَنِ ابْنِ فُضَيْلٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنِ الْمِنْهَالِ بْنِ عَمْرٍو، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم دَعَوَاتٌ لاَ يَدَعُهُنَّ كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْهَمِّ وَالْحَزَنِ وَالْعَجْزِ وَالْكَسَلِ وَالْبُخْلِ وَالْجُبْنِ وَغَلَبَةِ الرِّجَالِ ‏"‏ ‏.‏\hadithno{5449}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah [SAW] had supplications that he never omitted to recite. He used to say: 'Allahumma inni a'udhu bika minal-hammi, wal-hazani, wal-'ajzi, wal-kasali, wal-bukhli, wal-jubni, wa ghalabatar-rijal (O Allah, I seek refuge with You from worry, grief, incapacity, laziness, miserliness, cowardice and being overpowered by (other) men}}
\hadithdefcmd{nasai}{5450}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم دَعَوَاتٌ لاَ يَدَعُهُنَّ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْهَمِّ وَالْحَزَنِ وَالْعَجْزِ وَالْكَسَلِ وَالْبُخْلِ وَالْجُبْنِ وَالدَّيْنِ وَغَلَبَةِ الرِّجَالِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا الصَّوَابُ وَحَدِيثُ ابْنِ فُضَيْلٍ خَطَأٌ ‏.‏\hadithno{5450}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah [SAW] had supplications that he never neglected. He used to say: 'Allahumma inni a'udhu bika minal-hammi, wal-hazani, wal-'ajzi, wal-kasali, wal-bukhli, wal-jubni, wad-daini, wa ghalabatar-rijal (O Allah, I seek refuge with You from worry, grief, incapacity, laziness, miserliness, cowardice, debt, and being overpowered by (other) men}}
\hadithdefcmd{nasai}{5451}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، قَالَ حَدَّثَنَا بِشْرٌ، عَنْ حُمَيْدٍ، قَالَ قَالَ أَنَسٌ كَانَ النَّبِيُّ صلى الله عليه وسلم يَدْعُو ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْكَسَلِ وَالْهَرَمِ وَالْجُبْنِ وَالْبُخْلِ وَفِتْنَةِ الدَّجَّالِ وَعَذَابِ الْقَبْرِ ‏"‏ ‏.‏\hadithno{5451}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{Anas said:"The Prophet [SAW] used to say in his supplication: 'Allahumma inni a'udhu bika minal-kasali, wal-harami, wal-jubni, wal-bukhli, wa fitnatid-dajjali, wa 'adhabil-qabr (O Allah, I seek refuge in You from laziness, old age, cowardice, miserliness, the tribulation of the Dajjal and the torment of the grave)}}
\hadithdefcmd{nasai}{5452}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، عَنْ أَبِيهِ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْعَجْزِ وَالْكَسَلِ وَالْهَرَمِ وَالْبُخْلِ وَالْجُبْنِ وَأَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ وَمِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏ ‏.‏\hadithno{5452}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas that:The Prophet [SAW] used to say: "Allahumma inni a'udhu bika minal-'ajzi, wal-kasali, wal-harami, wal-bukhli, wal-jubni, wa 'audhu bika min 'adhabil-qabri, wa min fitnatil-mahya wal-mamati (O Allah, I seek refuge in You from incapacity, laziness, old age, miserliness and cowardice, and I seek refuge in You from the torment of the grave, and from the trials of life and death)}}
\hadithdefcmd{nasai}{5453}{أَخْبَرَنَا أَبُو حَاتِمٍ السِّجِسْتَانِيُّ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنِي عَمْرُو بْنُ أَبِي عَمْرٍو، مَوْلَى الْمُطَّلِبِ عَنْ عَبْدِ اللَّهِ بْنِ الْمُطَّلِبِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا دَعَا قَالَ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْهَمِّ وَالْحَزَنِ وَالْعَجْزِ وَالْكَسَلِ وَالْبُخْلِ وَالْجُبْنِ وَضَلَعِ الدَّيْنِ وَغَلَبَةِ الرِّجَالِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ سَعِيدُ بْنُ سَلَمَةَ شَيْخٌ ضَعِيفٌ وَإِنَّمَا أَخْرَجْنَاهُ لِلزِّيَادَةِ فِي الْحَدِيثِ ‏.‏\hadithno{5453}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas bin Malik, that :When the Messenger of Allah [SAW] supplicated, he would say: "Allahumma inni a'udhu bika minal-hammi, wal-hazani, wal-'ajzi, wal-kasali, wal-bukhli, wal-jubni, wad-dala'id-daini, wa ghalabatir-rijal (O Allah, I seek refuge with You from worry, grief, incapacity, laziness, miserliness, cowardice, difficult debt and being overpowered by men)}}
\hadithdefcmd{nasai}{5454}{أَخْبَرَنِي مُحَمَّدُ بْنُ عُثْمَانَ بْنِ أَبِي صَفْوَانَ، قَالَ حَدَّثَنِي سَلَمَةُ بْنُ سَعِيدِ بْنِ عَطِيَّةَ، - وَكَانَ خَيْرَ أَهْلِ زَمَانِهِ - قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَكْثَرَ مَا يَتَعَوَّذُ مِنَ الْمَغْرَمِ وَالْمَأْثَمِ قُلْتُ يَا رَسُولَ اللَّهِ مَا أَكْثَرَ مَا تَتَعَوَّذُ مِنَ الْمَغْرَمِ قَالَ ‏ "‏ إِنَّهُ مَنْ غَرِمَ حَدَّثَ فَكَذَبَ وَوَعَدَ فَأَخْلَفَ ‏"‏ ‏.‏\hadithno{5454}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah [SAW] often used to seek refuge (with Allah) from debt and sin. I said: 'O Messenger of Allah, how often you seek refuge from debt!' He said: 'Whoever gets into debt speaks and lies, and makes a promise and breaks it}}
\hadithdefcmd{nasai}{5455}{أَخْبَرَنَا الْحُسَيْنُ بْنُ إِسْحَاقَ، قَالَ أَنْبَأَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا سَعْدُ بْنُ أَوْسٍ، قَالَ حَدَّثَنِي بِلاَلُ بْنُ يَحْيَى، أَنَّ شُتَيْرَ بْنَ شَكَلٍ، أَخْبَرَهُ عَنْ أَبِيهِ، شَكَلِ بْنِ حُمَيْدٍ قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ يَا نَبِيَّ اللَّهِ عَلِّمْنِي تَعَوُّذًا أَتَعَوَّذُ بِهِ فَأَخَذَ بِيَدِي ثُمَّ قَالَ ‏ "‏ قُلْ أَعُوذُ بِكَ مِنْ شَرِّ سَمْعِي وَشَرِّ بَصَرِي وَشَرِّ لِسَانِي وَشَرِّ قَلْبِي وَشَرِّ مَنِيِّي ‏"‏ ‏.‏ قَالَ حَتَّى حَفِظْتُهَا قَالَ سَعْدٌ وَالْمَنِيُّ مَاؤُهُ ‏.‏ خَالَفَهُ وَكِيعٌ فِي لَفْظِهِ ‏.‏\hadithno{5455}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Shakal bin Humaid said:"I came to the Prophet [SAW] and said: 'O Prophet of Allah, teach me words by which I may seek refuge (with Allah).' He took me by the hand then said: 'Say: A'udhu bika min sharri sam'i, wa sharri basari, wa sharri lisani, wa sharri qalbi, wa sharri mani (I seek refuge in You from the evil of my hearing, the evil of my seeing, the evil of my tongue, the evil of my heart, and the evil of my sperm),' until I had memorized it." Waki' contradicted him in the wordings}}
\hadithdefcmd{nasai}{5456}{أَخْبَرَنَا عُبَيْدُ بْنُ وَكِيعِ بْنِ الْجَرَّاحِ، قَالَ حَدَّثَنَا أَبِي، عَنْ سَعْدِ بْنِ أَوْسٍ، عَنْ بِلاَلِ بْنِ يَحْيَى، عَنْ شُتَيْرِ بْنِ شَكَلِ بْنِ حُمَيْدٍ، عَنْ أَبِيهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ عَلِّمْنِي دُعَاءً أَنْتَفِعُ بِهِ ‏.‏ قَالَ ‏ "‏ قُلِ اللَّهُمَّ عَافِنِي مِنْ شَرِّ سَمْعِي وَبَصَرِي وَلِسَانِي وَقَلْبِي وَمِنْ شَرِّ مَنِيِّي ‏"‏ ‏.‏ يَعْنِي ذَكَرَهُ ‏.‏\hadithno{5456}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Shutair bin Shakal bin Humaid, that his father said:"I said: 'O Messenger of Allah, teach me a supplication from which I may benefit.' He said: 'Say: Allahumma 'afini min sharri sam'i, wa basari, wa lisani, wa qalbi, wa min sharri mani (O Allah, protect me from the evil of my hearing, my seeing, my tongue and my heart, and from the evil of my sperm.)'" - Meaning sexual organ}}
\hadithdefcmd{nasai}{5457}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ خَالِدٍ، قَالَ حَدَّثَنَا حُمَيْدٌ، قَالَ سُئِلَ أَنَسٌ - وَهُوَ ابْنُ مَالِكٍ - عَنْ عَذَابِ الْقَبْرِ، وَعَنِ الدَّجَّالِ، قَالَ كَانَ نَبِيُّ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْكَسَلِ وَالْهَرَمِ وَالْجُبْنِ وَالْبُخْلِ وَفِتْنَةِ الدَّجَّالِ وَعَذَابِ الْقَبْرِ ‏"‏ ‏.‏\hadithno{5457}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Khalid said:"Humaid narrated: 'Anas - bin Malik - was asked about the torment of the grave and about the Dajjal. He said: "The Prophet of Allah [SAW] used to say: Allahumma, inni a'udhu bika minal-kasali, wal-harami, wal-jubni, wal-bukhli, wa fitnatid-dajjali, wa 'adhabil-qabr (O Allah, I seek refuge with You from laziness, old age, cowardice, stinginess, the tribulation of the Dajjal and the torment of the grave)}}
\hadithdefcmd{nasai}{5458}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا مُحَاضِرٌ، قَالَ حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ لاَ أُعَلِّمُكُمْ إِلاَّ مَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعَلِّمُنَا يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْعَجْزِ وَالْكَسَلِ وَالْبُخْلِ وَالْجُبْنِ وَالْهَرَمِ وَعَذَابِ الْقَبْرِ اللَّهُمَّ آتِ نَفْسِي تَقْوَاهَا وَزَكِّهَا أَنْتَ خَيْرُ مَنْ زَكَّاهَا أَنْتَ وَلِيُّهَا وَمَوْلاَهَا اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ قَلْبٍ لاَ يَخْشَعُ وَمِنْ نَفْسٍ لاَ تَشْبَعُ وَعِلْمٍ لاَ يَنْفَعُ وَدَعْوَةٍ لاَ يُسْتَجَابُ لَهَا ‏"‏ ‏.‏\hadithno{5458}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Zaid bin Arqam said:"I will not teach you anything but that which the Messenger of Allah [SAW] used to teach us. He said: 'Allahumma inni a'udhu bika min al-'ajzi wal-kasali, wal-bukhli, wal-jubni, wal-harami, wa 'adhabil-qabri, Allahumma ati nafsi taqwaha, wa zakkiha anta khairu min zakkaha, anta waliyyuha wa mawlaha. Allahumma inni a'udhu bika min qalbin la yakhsha'u wa min nafsin la tashba'u wa 'ilmin la yanfa'u wa da'watin la yustajabu laha (O Allah, I seek refuge in You from incapacity, laziness, miserliness, cowardice, old age, the torment of the grave. O Allah, make my soul obedient and purify it, for You are the best One to purify it, You are its Guardian and Lord. O Allah, I seek refuge in You from a heart that is not humble, a soul that is not satisfied, knowledge that is of no benefit and a supplication that is not answered)}}
\hadithdefcmd{nasai}{5459}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْعَجْزِ وَالْكَسَلِ وَالْبُخْلِ وَالْجُبْنِ وَالْهَرَمِ وَعَذَابِ الْقَبْرِ وَفِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏ ‏.‏\hadithno{5459}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas that:The Prophet of Allah [SAW] said: "Allahumma inni a'udhu bika min al-'ajzi, wal-kasali, wal-bukhli, wal-jubni, wal-harami, wa 'adhabil-qabri, wa fitnatil-mahya wal-mamat (O Allah, I seek refuge in You from incapacity, laziness, miserliness, cowardice, old age, the torment of the grave and the trials of life and death)}}
\hadithdefcmd{nasai}{5460}{أَخْبَرَنَا أَبُو عَاصِمٍ، خُشَيْشُ بْنُ أَصْرَمَ قَالَ حَدَّثَنَا حَبَّانُ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ سَعِيدِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْفَقْرِ وَأَعُوذُ بِكَ مِنَ الْقِلَّةِ وَالذِّلَّةِ وَأَعُوذُ بِكَ أَنْ أَظْلِمَ أَوْ أُظْلَمَ ‏"‏ ‏.‏ خَالَفَهُ الأَوْزَاعِيُّ ‏.‏\hadithno{5460}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah [SAW] used to say: "Allahumma, inni a'udhu bika minal-faqri wa a'udhu bika min al-qillati wadh-dhillati, wa a'udhu bika an azlima aw uzlam (O Allah, I seek refuge with you from poverty, I seek refuge with You from want and humiliation, and I seek refuge with You from wronging others or being wronged.)" Al-Awza'I contradicted him}}
\hadithdefcmd{nasai}{5461}{قَالَ أَخْبَرَنِي مَحْمُودُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا الْوَلِيدُ، عَنْ أَبِي عَمْرٍو، - وَهُوَ الأَوْزَاعِيُّ - قَالَ حَدَّثَنِي إِسْحَاقُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، قَالَ حَدَّثَنِي جَعْفَرُ بْنُ عِيَاضٍ، قَالَ حَدَّثَنِي أَبُو هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَعَوَّذُوا بِاللَّهِ مِنَ الْفَقْرِ وَالْقِلَّةِ وَالذِّلَّةِ وَأَنْ تَظْلِمَ أَوْ تُظْلَمَ ‏"‏ ‏.‏\hadithno{5461}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah said:"The Messenger of Allah [SAW] said: 'Seek refuge with Allah from poverty, want, humiliation and wronging others or being wronged}}
\hadithdefcmd{nasai}{5462}{أَخْبَرَنَا أَحْمَدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ إِسْحَاقَ، عَنْ سَعِيدِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْقِلَّةِ وَالْفَقْرِ وَالذِّلَّةِ وَأَعُوذُ بِكَ أَنْ أَظْلِمَ أَوْ أُظْلَمَ ‏"‏ ‏.‏\hadithno{5462}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah,:From the Prophet [SAW], that he used to say: "Allahumma inni a'udhu bika minal-qillati wal-faqri, wadh-dhillati wa a'udhu bika min azlima aw uzlam (O Allah, I seek refuge with You from want, poverty and humiliation, and I seek refuge with You from wronging others or being wronged)}}
\hadithdefcmd{nasai}{5463}{أَخْبَرَنَا مَحْمُودُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا عُمَرُ، - يَعْنِي ابْنَ عَبْدِ الْوَاحِدِ - عَنِ الأَوْزَاعِيِّ، قَالَ حَدَّثَنِي إِسْحَاقُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي جَعْفَرُ بْنُ عِيَاضٍ، قَالَ حَدَّثَنِي أَبُو هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَعَوَّذُوا بِاللَّهِ مِنَ الْفَقْرِ وَمِنَ الْقِلَّةِ وَمِنَ الذِّلَّةِ وَأَنْ أَظْلِمَ أَوْ أُظْلَمَ ‏"‏ ‏.‏\hadithno{5463}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah said:"The Messenger of Allah [SAW] said: 'Seek refuge with Allah from poverty, want and humiliation, and from wronging others or being wronged}}
\hadithdefcmd{nasai}{5464}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي مُوسَى بْنُ شَيْبَةَ، عَنِ الأَوْزَاعِيِّ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، قَالَ حَدَّثَنِي جَعْفَرُ بْنُ عِيَاضٍ، أَنَّ أَبَا هُرَيْرَةَ، حَدَّثَهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تَعَوَّذُوا بِاللَّهِ مِنَ الْفَقْرِ وَالْقِلَّةِ وَالذِّلَّةِ وَأَنْ تَظْلِمَ أَوْ تُظْلَمَ ‏"‏ ‏.‏\hadithno{5464}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah narrated that:The Messenger of Allah [SAW] said: "Seek refuge with Allah from poverty, want and humiliation, and from wronging others or being wronged}}
\hadithdefcmd{nasai}{5465}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، قَالَ حَدَّثَنَا عُثْمَانُ، - يَعْنِي الشَّحَّامَ - قَالَ حَدَّثَنَا مُسْلِمٌ، - يَعْنِي ابْنَ أَبِي بَكْرَةَ - أَنَّهُ كَانَ سَمِعَ وَالِدَهُ، يَقُولُ فِي دُبُرِ الصَّلاَةِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْكُفْرِ وَالْفَقْرِ وَعَذَابِ الْقَبْرِ ‏"‏ ‏.‏ فَجَعَلْتُ أَدْعُو بِهِنَّ فَقَالَ يَا بُنَىَّ أَنَّى عُلِّمْتَ هَؤُلاَءِ الْكَلِمَاتِ قُلْتُ يَا أَبَتِ سَمِعْتُكَ تَدْعُو بِهِنَّ فِي دُبُرِ الصَّلاَةِ فَأَخَذْتُهُنَّ عَنْكَ ‏.‏ قَالَ فَالْزَمْهُنَّ يَا بُنَىَّ فَإِنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ يَدْعُو بِهِنَّ فِي دُبُرِ الصَّلاَةِ ‏.‏\hadithno{5465}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{Muslim - meaning bin Abi Bakrah - narrated that:He heard his father say following the prayer: "Allahumma inni a'udhu bika minal-kufri wal-faqri, wa 'adhabil-qabri (O Allah, I seek refuge with You from Kufr, poverty and the torment of the grave.)" I started to recite them and he said: "O my son, where did you learn these words?" I said: "O my father, I heard you saying this supplication at the end of the prayer, and I learned them from you." He said: "Continue to recite them, O my son, for the Prophet of Allah [SAW] used to say this supplication at the end of the prayer}}
\hadithdefcmd{nasai}{5466}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم كَثِيرًا مَا يَدْعُو بِهَؤُلاَءِ الْكَلِمَاتِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ فِتْنَةِ النَّارِ وَعَذَابِ النَّارِ وَفِتْنَةِ الْقَبْرِ وَعَذَابِ الْقَبْرِ وَشَرِّ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ وَشَرِّ فِتْنَةِ الْفَقْرِ وَشَرِّ فِتْنَةِ الْغِنَى اللَّهُمَّ اغْسِلْ خَطَايَاىَ بِمَاءِ الثَّلْجِ وَالْبَرَدِ وَأَنْقِ قَلْبِي مِنَ الْخَطَايَا كَمَا أَنْقَيْتَ الثَّوْبَ الأَبْيَضَ مِنَ الدَّنَسِ وَبَاعِدْ بَيْنِي وَبَيْنَ خَطَايَاىَ كَمَا بَاعَدْتَ بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْكَسَلِ وَالْهَرَمِ وَالْمَأْثَمِ وَالْمَغْرَمِ ‏"‏ ‏.‏\hadithno{5466}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah [SAW] often used to say these words in his supplication: 'Allahumma, inni a'udhu bika min fitnatin-nari, wa 'adhabin-nari, wa fitnatil-qabri, wa 'adhabil-qabr, wa sharri fitnatil masihid-dajjal, wa sharri fitnatil-faqri, wa sharri fitnatil-ghina. Allahummaghsil khatayaya bima'ith-thalji wal-baradi wa anqi qalbi minal-khataya kama anqaitath-thawbal-abyada min ad-danasi, wa ba'id baini wa baina khatayaya kama ba'adta bainal-mashriqi wal-maghrib. Allahumma inni a'udhu bika min al-kasali wal harami, wal ma'thami wal-maghram (O Allah, I seek refuge with You from the tribulation of the Fire and the torment of the Fire, from the tribulation of the grave and the torment of the grave, from the evil of the tribulation of the Al-Masihid-Dajjal, from the evil of the tribulation of poverty and from the evil of the tribulation of richness. O Allah, wash away my sins with the water of snow and hail, and cleanse my heart from all the sins as you would cleanse white garment from the filth, and put a great distance between me and my sins, as great as the distance You have made between the East and the West. O Allah, I seek refuge in You from laziness, old age, sin and debt)}}
\hadithdefcmd{nasai}{5467}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَخِيهِ، عَبَّادِ بْنِ أَبِي سَعِيدٍ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الأَرْبَعِ مِنْ عِلْمٍ لاَ يَنْفَعُ وَمِنْ قَلْبٍ لاَ يَخْشَعُ وَمِنْ نَفْسٍ لاَ تَشْبَعُ وَمِنْ دُعَاءٍ لاَ يُسْمَعُ ‏"‏ ‏.‏\hadithno{5467}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah said:"The Messenger of Allah [SAW] used to say: 'Allahumma inni a'udhu bika min al-arba': min 'ilmin la yanfa'u, wa min qalbin la yakhsha'u, wa min nafsin la tashba'u, wa min du'a'in la yusma'u (O Allah, I seek refuge in You from four: From knowledge that is of no benefit, from a heart that is not humble, from a soul that is not satisfied and from a supplication that is not answered)}}
\hadithdefcmd{nasai}{5468}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ أَنْبَأَنَا ابْنُ إِدْرِيسَ، عَنِ ابْنِ عَجْلاَنَ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْجُوعِ فَإِنَّهُ بِئْسَ الضَّجِيعُ وَأَعُوذُ بِكَ مِنَ الْخِيَانَةِ فَإِنَّهَا بِئْسَتِ الْبِطَانَةُ ‏"‏ ‏.‏\hadithno{5468}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] said: 'Allahumma inni a'udhu bika minal-ju'I, fa innahu bi'sad-daji'u, wa a'udhu bika minal-khiyanati, fa innahu bi'satil-bitanah (O Allah, I seek refuge in You from hunger, for it is a bad companion, and I seek refuge with You from treachery, for it is a bad thing to hide in one's heart)}}
\hadithdefcmd{nasai}{5469}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، قَالَ حَدَّثَنَا ابْنُ عَجْلاَنَ، وَذَكَرَ، آخَرَ عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْجُوعِ فَإِنَّهُ بِئْسَ الضَّجِيعُ وَمِنَ الْخِيَانَةِ فَإِنَّهَا بِئْسَتِ الْبِطَانَةُ ‏"‏ ‏.‏\hadithno{5469}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] used to say: 'Allahumma inni a'udhu bika minal-ju'i, fa innahu bi'sad-daji'u, wa a'udhu bika minal-khiyanati, fa innahu bi'satil-bitanah (O Allah, I seek refuge in You from hunger, for it is a bad companion, and I seek refuge with You from treachery, for it is a bad thing to hide in one's heart)}}
\hadithdefcmd{nasai}{5470}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا خَلَفٌ، عَنْ حَفْصٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَدْعُو بِهَذِهِ الدَّعَوَاتِ ‏"‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عِلْمٍ لاَ يَنْفَعُ وَقَلْبٍ لاَ يَخْشَعُ وَدُعَاءٍ لاَ يُسْمَعُ وَنَفْسٍ لاَ تَشْبَعُ ‏"‏ ‏.‏ ثُمَّ يَقُولُ ‏"‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ هَؤُلاَءِ الأَرْبَعِ ‏"‏ ‏.‏\hadithno{5470}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas that :The Prophet [SAW] used to say these supplications: "Allahumma inni a'udhu bika min 'ilmin la yanfa'u, wa qalbin la yakhsha'u, wa du'a'in la yasma'u, wa nafsin la tashba'u. (O Allah, I seek refuge with You from knowledge that is of no benefit, a heart that is not humble, a supplication that is not heard and a soul that is not satisfied.)" Then he would say: 'Allahumma inni a'udhu bika min ha'ula'il-arba' (O Allah, I seek refuge with You from these four)}}
\hadithdefcmd{nasai}{5471}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَقِيَّةُ، قَالَ حَدَّثَنَا ضُبَارَةُ، عَنْ دُوَيْدِ بْنِ نَافِعٍ، قَالَ قَالَ أَبُو صَالِحٍ قَالَ أَبُو هُرَيْرَةَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَدْعُو ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الشِّقَاقِ وَالنِّفَاقِ وَسُوءِ الأَخْلاَقِ ‏"‏ ‏.‏\hadithno{5471}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah said:"The Messenger of Allah [SAW] used to say in his supplication: 'Allahumma inni a'udhu bika minash-shiqaqi wan-nifaqi, wa suw'il-akhlaq (O Allah, I seek refuge with You from opposing the truth, hypocrisy and bad manners)}}
\hadithdefcmd{nasai}{5472}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا بَقِيَّةُ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ، سُلَيْمَانُ بْنُ سُلَيْمٍ الْحِمْصِيُّ قَالَ حَدَّثَنِي الزُّهْرِيُّ، عَنْ عُرْوَةَ، - هُوَ ابْنُ الزُّبَيْرِ - عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُكْثِرُ التَّعَوُّذَ مِنَ الْمَغْرَمِ وَالْمَأْثَمِ فَقِيلَ لَهُ يَا رَسُولَ اللَّهِ إِنَّكَ تُكْثِرُ التَّعَوُّذَ مِنَ الْمَغْرَمِ وَالْمَأْثَمِ فَقَالَ ‏ "‏ إِنَّ الرَّجُلَ إِذَا غَرِمَ حَدَّثَ فَكَذَبَ وَوَعَدَ فَأَخْلَفَ ‏"‏ ‏.‏\hadithno{5472}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah [SAW] often used to seek refuge (with Allah) from debt and sin. It was said to him: 'O Messenger of Allah! You often seek refuge from debt and sin?' He said: 'If a man gets into debt, he speaks and lies, and he makes a promise and breaks it}}
\hadithdefcmd{nasai}{5473}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا حَيْوَةُ، وَذَكَرَ، آخَرَ قَالَ حَدَّثَنَا سَالِمُ بْنُ غَيْلاَنَ التُّجِيبِيُّ، أَنَّهُ سَمِعَ دَرَّاجًا أَبَا السَّمْحِ، أَنَّهُ سَمِعَ أَبَا الْهَيْثَمِ، أَنَّهُ سَمِعَ أَبَا سَعِيدٍ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ أَعُوذُ بِاللَّهِ مِنَ الْكُفْرِ وَالدَّيْنِ ‏"‏ ‏.‏ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَتَعْدِلُ الدَّيْنَ بِالْكُفْرِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ ‏"‏ ‏.‏\hadithno{5473}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Sa'eed said:"I heard the Messenger of Allah [SAW] say: 'A'udhu billahi minal-kufri wad-dain. (I seek refuge with Allah from Kufr and debt.)' A man said: 'O Messenger of Allah, are you equating debt with Kufr?' The Messenger of Allah [SAW] said: 'Yes}}
\hadithdefcmd{nasai}{5474}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، قَالَ حَدَّثَنَا حَيْوَةُ، عَنْ دَرَّاجٍ أَبِي السَّمْحِ، عَنْ أَبِي الْهَيْثَمِ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ أَعُوذُ بِاللَّهِ مِنَ الْكُفْرِ وَالدَّيْنِ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ تَعْدِلُ الدَّيْنَ بِالْكُفْرِ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏\hadithno{5474}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Sa'eed that:The Prophet [SAW] said: "A'udhu billahi minal-kufri wad-dain. (I seek refuge with Allah from Kufr and debt.)" A man said: "Are you equating debt with Kufr?" He said: "Yes}}
\hadithdefcmd{nasai}{5475}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي حُيَىُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي أَبُو عَبْدِ الرَّحْمَنِ الْحُبُلِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَدْعُو بِهَؤُلاَءِ الْكَلِمَاتِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ غَلَبَةِ الدَّيْنِ وَغَلَبَةِ الْعَدُوِّ وَشَمَاتَةِ الأَعْدَاءِ ‏"‏ ‏.‏\hadithno{5475}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdullah bin 'Amr bin Al-'As that:The Messenger of Allah [SAW] used to say these words in his supplication: "Allahumma inni a'udhu bika min ghalabatid-dain, wa ghalabatil-'aduwwi, wa shamatatil-a'da'. (O Allah, I seek refuge with You from being overwhelmed with debt, from being overpowered by the enemy and from the enemy rejoicing over my misfortunes)}}
\hadithdefcmd{nasai}{5476}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا الْقَاسِمُ، وَهُوَ ابْنُ يَزِيدَ الْجَرْمِيُّ عَنْ عَبْدِ الْعَزِيزِ، أَخْبَرَنِي عَمْرُو بْنُ أَبِي عَمْرٍو، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْهَمِّ وَالْحَزَنِ وَالْكَسَلِ وَالْبُخْلِ وَالْجُبْنِ وَضَلَعِ الدَّيْنِ وَغَلَبَةِ الرِّجَالِ ‏"‏ ‏.‏\hadithno{5476}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas bin Malik said:"The Prophet [SAW] used to say: 'Allahumma inni a'udhu bika minal-hammi wal hazani, wal-kasali, wal-bukhli, wal-jubni, wa dala'id-dain, wa ghalabatir-rijal (O Allah, I seek refuge with You from worry, grief, laziness, miserliness, cowardice, difficult debt and being overpowered by men)}}
\hadithdefcmd{nasai}{5477}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ وَفِتْنَةِ النَّارِ وَفِتْنَةِ الْقَبْرِ وَعَذَابِ الْقَبْرِ وَشَرِّ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ وَشَرِّ فِتْنَةِ الْغِنَى وَشَرِّ فِتْنَةِ الْفَقْرِ اللَّهُمَّ اغْسِلْ خَطَايَاىَ بِمَاءِ الثَّلْجِ وَالْبَرَدِ وَنَقِّ قَلْبِي مِنَ الْخَطَايَا كَمَا نَقَّيْتَ الثَّوْبَ الأَبْيَضَ مِنَ الدَّنَسِ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْكَسَلِ وَالْهَرَمِ وَالْمَغْرَمِ وَالْمَأْثَمِ ‏"‏ ‏.‏\hadithno{5477}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah [SAW] used to say: 'Allahumma inni a'udhu bika min 'adhabil-qabri, wa fitnatin-nar, wa fitnatil-qabr, wa 'adhabil-qabr, wa sharri fitnati masihid-dajjali wa sharri fitnatil-ghana', wa sharri fitnatil-faqri. Allahummaghsil khatayaya kama naqqaitath-thawbal-abyada minad-danas. Allahumma inni a'udhu bika minal-kasali walharami wal-maghrami wal-ma'tham (O Allah, I seek refuge with You from the torment of the grave, the tribulation of the Fire, the tribulation of the grave and the torment of the grave, the evil of the tribulation of Masihid-Dajjal, the evil of the tribulation of richness and the evil of the tribulation of poverty. O Allah, wash away my sins with water of snow and hail, and cleanse my heart of sin as a white garment is cleansed of filth. O Allah, I seek refuge with You from laziness, old age, debt and sin)}}
\hadithdefcmd{nasai}{5478}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، قَالَ سَمِعْتُ مُصْعَبَ بْنَ سَعْدٍ، قَالَ كَانَ سَعْدٌ يُعَلِّمُهُ هَؤُلاَءِ الْكَلِمَاتِ وَيَرْوِيهِنَّ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْبُخْلِ وَأَعُوذُ بِكَ مِنَ الْجُبْنِ وَأَعُوذُ بِكَ مِنْ أَنْ أُرَدَّ إِلَى أَرْذَلِ الْعُمُرِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الدُّنْيَا وَعَذَابِ الْقَبْرِ ‏"‏ ‏.‏\hadithno{5478}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Mus'ab bin Sa'd said that :Sa'd used to teach him these words, narrating from the Prophet [SAW]: "Allahumma inni a'udhu bika minal-bukhli, wa a'udhu bika minal-jubni, wa a'udhu bika an uradda ila ardhalil-'umuri, wa a'udhu bika min fitnatid-dunya wa 'adhabil-qabr (O Allah, I seek refuge with You from miserliness, and I seek refuge with You from cowardice, and I seek refuge with You from reaching the age of senility, and I seek refuge in You from the trials of this world and the torment of the grave)}}
\hadithdefcmd{nasai}{5479}{أَخْبَرَنِي هِلاَلُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ إِسْرَائِيلَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، وَعَمْرِو بْنِ مَيْمُونٍ الأَوْدِيِّ، قَالاَ كَانَ سَعْدٌ يُعَلِّمُ بَنِيهِ هَؤُلاَءِ الْكَلِمَاتِ كَمَا يُعَلِّمُ الْمُكْتِبُ الْغِلْمَانَ وَيَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَتَعَوَّذُ بِهِنَّ فِي دُبُرِ كُلِّ صَلاَةٍ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْبُخْلِ وَأَعُوذُ بِكَ مِنَ الْجُبْنِ وَأَعُوذُ بِكَ مِنْ أَنْ أُرَدَّ إِلَى أَرْذَلِ الْعُمُرِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الدُّنْيَا وَعَذَابِ الْقَبْرِ ‏"‏ ‏.‏\hadithno{5479}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Mus'ab bin Sa'd and 'Amr bin Maimun Al-Awdi said:"Sa'd used to teach his children these words as a teacher teaches his students, and he would say that the Messenger of Allah [SAW] used to seek refuge (with Allah) with these words at the end of every prayer: 'Allahumma inni a'udhu bika minal-bukhli, wa a'udhu bika mnal-jubni, wa a'udhu bika an uradda ila ardhalil-'umuri, wa a'udhu bika min fitnatid-dunya, wa min 'adhabil-qabr (O Allah, I seek refuge with You from miserliness, and I seek refuge with You from cowardice, and I seek refuge with You from reaching the age of senility, and I seek refuge with You from the trials of this life and the torment of the grave)}}
\hadithdefcmd{nasai}{5480}{أَخْبَرَنَا أَحْمَدُ بْنُ فَضَالَةَ، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَنْبَأَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَتَعَوَّذُ مِنَ الْجُبْنِ وَالْبُخْلِ وَسُوءِ الْعُمُرِ وَفِتْنَةِ الصَّدْرِ وَعَذَابِ الْقَبْرِ ‏.‏\hadithno{5480}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Umar that:The Prophet [SAW] used to seek refuge with Allah from cowardice, miserliness, reaching the age of second childhood, the trials of the heart and the torment of the grave}}
\hadithdefcmd{nasai}{5481}{أَخْبَرَنَا سُلَيْمَانُ بْنُ سَلْمٍ الْبَلْخِيُّ، - هُوَ أَبُو دَاوُدَ الْمَصَاحِفِيُّ - قَالَ أَنْبَأَنَا النَّضْرُ، قَالَ أَنْبَأَنَا يُونُسُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَعَوَّذُ مِنْ خَمْسٍ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْجُبْنِ وَالْبُخْلِ وَسُوءِ الْعُمُرِ وَفِتْنَةِ الصَّدْرِ وَعَذَابِ الْقَبْرِ ‏"‏ ‏.‏\hadithno{5481}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Urwah bin Maimun said:"I heard 'Umar bin Al-Khattab say: 'The Messenger of Allah [SAW] used to seek refuge with Allah from five things and say: Allahumma inni a'udhu bika minal-jubni, wal-bukhli, wa suw'il-'umuri, wa fitnatis-sadri wa 'adhabil-qabr (O Allah, I seek refuge with You from cowardice, miserliness, reaching the age of second childhood, the trials of the heart and the torment of the grave)}}
\hadithdefcmd{nasai}{5482}{أَخْبَرَنِي هِلاَلُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا حُسَيْنٌ، قَالَ حَدَّثَنَا زُهَيْرٌ، قَالَ حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، قَالَ حَدَّثَنِي أَصْحَابُ، مُحَمَّدٍ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَتَعَوَّذُ مِنَ الشُّحِّ وَالْجُبْنِ وَفِتْنَةِ الصَّدْرِ وَعَذَابِ الْقَبْرِ ‏.‏\hadithno{5482}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Amr bin Maimun said:"The Companions of Muhammad [SAW] told me that the Messenger of Allah [SAW] used to seek refuge with Allah from stinginess, cowardice, the trials of the heart and the torment of the grave}}
\hadithdefcmd{nasai}{5483}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَتَعَوَّذُ مُرْسَلٌ ‏.‏\hadithno{5483}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Amr bin Maimun said:"The Prophet [SAW] used to seek refuge." Mursal}}
\hadithdefcmd{nasai}{5484}{أَخْبَرَنِي عُبَيْدُ بْنُ وَكِيعٍ، قَالَ حَدَّثَنَا أَبِي، عَنْ سَعْدِ بْنِ أَوْسٍ، عَنْ بِلاَلِ بْنِ يَحْيَى، عَنْ شُتَيْرِ بْنِ شَكَلِ بْنِ حُمَيْدٍ، عَنْ أَبِيهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ عَلِّمْنِي دُعَاءً أَنْتَفِعُ بِهِ ‏.‏ قَالَ ‏ "‏ قُلِ اللَّهُمَّ عَافِنِي مِنْ شَرِّ سَمْعِي وَبَصَرِي وَلِسَانِي وَقَلْبِي وَشَرِّ مَنِيِّي ‏"‏ ‏.‏ يَعْنِي ذَكَرَهُ ‏.‏\hadithno{5484}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Shutair bin Shakal bin Humaid, that his father said:"I said: 'O Messenger of Allah, teach me a supplication from which I may benefit.' He said: 'Say: Allahumma 'afini min sharri sam'i, wa basari, wa lisani, wa qalbi, wa sharri mani (O Allah, protect me from the evil of my hearing, my seeing, my tongue and my heart, and the evil of my sperm.)" - Meaning his sexual organ}}
\hadithdefcmd{nasai}{5485}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ غَيْلاَنَ، عَنْ دَرَّاجٍ أَبِي السَّمْحِ، عَنْ أَبِي الْهَيْثَمِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ كَانَ يَقُولُ ‏"‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْكُفْرِ وَالْفَقْرِ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ وَيَعْدِلاَنِ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏\hadithno{5485}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that:The Messenger of Allah [SAW] used to say: "A'udhu billahi minal-kufri wal-faqr. (O Allah, I seek refuge with You from Kufr and poverty.)" A man said: "Are they equal?" He said: "Yes}}
\hadithdefcmd{nasai}{5486}{أَخْبَرَنِي مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنِ الشَّعْبِيِّ، عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا خَرَجَ مِنْ بَيْتِهِ قَالَ ‏ "‏ بِسْمِ اللَّهِ رَبِّ أَعُوذُ بِكَ مِنْ أَنْ أَزِلَّ أَوْ أَضِلَّ أَوْ أَظْلِمَ أَوْ أُظْلَمَ أَوْ أَجْهَلَ أَوْ يُجْهَلَ عَلَىَّ ‏"‏ ‏.‏\hadithno{5486}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Umm Salamah that :When the Prophet [SAW] went out of his house, he said: "Bismillahi Rabbi! A'udhu bika min an azilla aw adilla aw azlima aw uzlama, aw ajhala aw yujhala 'alayya (In the name of Allah, my Lord, I seek refuge in You from falling into error or going astray, or wrongdoing (others) or being wronged, and from behaving or being treated in an ignorant manner}}
\hadithdefcmd{nasai}{5487}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي حُيَىُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي أَبُو عَبْدِ الرَّحْمَنِ الْحُبُلِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَدْعُو بِهَؤُلاَءِ الْكَلِمَاتِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ غَلَبَةِ الدَّيْنِ وَغَلَبَةِ الْعَدُوِّ وَشَمَاتَةِ الأَعْدَاءِ ‏"‏ ‏.‏\hadithno{5487}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin 'Amr bin Al-'As that:The Messenger of Allah [SAW] used to say supplication in these words: "Allahumma inni a'udhu bika min ghalabatid-dain, wa ghalabatil-'aduwwi, wa shamatatil-a'da'. (O Allah, I seek refuge with You from being overwhelmed by debt and from being overpowered by the enemy, and from the enemy rejoicing at my misfortune)}}
\hadithdefcmd{nasai}{5488}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ قَالَ حُيَىٌّ حَدَّثَنِي أَبُو عَبْدِ الرَّحْمَنِ الْحُبُلِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَدْعُو بِهَؤُلاَءِ الْكَلِمَاتِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ غَلَبَةِ الدَّيْنِ وَشَمَاتَةِ الأَعْدَاءِ ‏"‏ ‏.‏\hadithno{5488}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin 'Amr that :The Messenger of Allah [SAW] used to say supplication in these words: "Allahumma inni a'udhu bika min ghalabatid-dain, wa ghalabatil-'aduwwi, wa shamatatil-a'da' (O Allah, I seek refuge with You from being overwhelmed by debt and from being overpowered by the enemy, and from the enemy rejoicing at my misfortune)}}
\hadithdefcmd{nasai}{5489}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ مَسْعَدَةَ، عَنْ هَارُونَ بْنِ إِبْرَاهِيمَ، عَنْ مُحَمَّدٍ، عَنْ عُثْمَانَ بْنِ أَبِي الْعَاصِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَدْعُو بِهَذِهِ الدَّعَوَاتِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْكَسَلِ وَالْهَرَمِ وَالْجُبْنِ وَالْعَجْزِ وَمِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏ ‏.‏\hadithno{5489}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Uthman bin Abi Al-'As that:The Prophet [SAW] used to say supplication in these words: "Allahumma inni a'udhu bika minal-kasali, walharami, wal-jubni, wal-'ajzi, wa min fitnatil-mahya wal-mamat. (O Allah, I seek refuge in You from laziness, old age, cowardice, and incapacity, and from the trials of life and death)}}
\hadithdefcmd{nasai}{5490}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، عَنِ اللَّيْثِ، عَنْ يَزِيدَ بْنِ الْهَادِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْكَسَلِ وَالْهَرَمِ وَالْمَغْرَمِ وَالْمَأْثَمِ وَأَعُوذُ بِكَ مِنْ شَرِّ الْمَسِيحِ الدَّجَّالِ وَأَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ وَأَعُوذُ بِكَ مِنْ عَذَابِ النَّارِ ‏"‏ ‏.‏\hadithno{5490}\hadithgrade{Abu Ghuddah: Hasan Sahih Isnaad; Al-Albani: Hasan Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, that his grandfather said:"I heard the Messenger of Allah [SAW] say: 'Allahumma inni a'udhu bika minal-kasali, walharami, wal-maghrami, wal-ma'thami, wa a'udhu bika min sharril-masihid-dajjali, wa a'udhu bika min 'adhabil-qabri, wa a'udhu bika min 'adhabin-nar (O Allah, I seek refuge in You from laziness, old age, debt and sin, and I seek refuge in You from the evil of the Al-Masihid-Dajjal, and I seek refuge in You from the torment of the grave, and I seek refuge in You from the punishment of the Fire)}}
\hadithdefcmd{nasai}{5491}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، إِنْ شَاءَ اللَّهُ عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَتَعَوَّذُ مِنْ هَذِهِ الثَّلاَثَةِ مِنْ دَرَكِ الشَّقَاءِ وَشَمَاتَةِ الأَعْدَاءِ وَسُوءِ الْقَضَاءِ وَجَهْدِ الْبَلاَءِ ‏.‏ قَالَ سُفْيَانُ هُوَ ثَلاَثَةٌ فَذَكَرْتُ أَرْبَعَةً لأَنِّي لاَ أَحْفَظُ الْوَاحِدَ الَّذِي لَيْسَ فِيهِ ‏.‏\hadithno{5491}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"The Prophet [SAW] used to seek refuge from these three: From being overtaken by destruction, from his enemies rejoicing in his misfortune, from being destined to an evil end, and from the difficult moment of a calamity." Sufyan (one of the narrators) said: "There were three, and I mentioned four because I do not remember which one was not one of them}}
\hadithdefcmd{nasai}{5492}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَسْتَعِيذُ مِنْ سُوءِ الْقَضَاءِ وَشَمَاتَةِ الأَعْدَاءِ وَدَرَكِ الشَّقَاءِ وَجَهْدِ الْبَلاَءِ ‏.‏\hadithno{5492}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that :The Prophet [SAW] used to seek refuge from being destined to an evil end, from his enemies rejoicing in his misfortune, from being overtaken by destruction and from the difficult moment of a calamity}}
\hadithdefcmd{nasai}{5493}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْجُنُونِ وَالْجُذَامِ وَالْبَرَصِ وَسَيِّيءِ الأَسْقَامِ ‏"‏ ‏.‏\hadithno{5493}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas that:The Prophet [SAW] used to say: "Allahumma inni a'udhu bika minal-jununi wal-jadhami, wal-barasi wa sayy'il-asqam (O Allah, I seek refuge in You from possession, leprosy, leukederma and bad sickness (that may lead to visible deformity)}}
\hadithdefcmd{nasai}{5494}{أَخْبَرَنَا هِلاَلُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا عَبَّادٌ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَعَوَّذُ مِنْ عَيْنِ الْجَانِّ وَعَيْنِ الإِنْسِ فَلَمَّا نَزَلَتِ الْمُعَوِّذَتَانِ أَخَذَ بِهِمَا وَتَرَكَ مَا سِوَى ذَلِكَ ‏.‏\hadithno{5494}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa'eed said:"The Messenger of Allah [SAW] used to seek refuge from the evil eye of the Jinn and the evil eye of humans. When Al-Mu'awwadhatan were revealed, he started to recite them and stopped reciting anything else}}
\hadithdefcmd{nasai}{5495}{أَخْبَرَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا حُسَيْنٌ، عَنْ زَائِدَةَ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَعَوَّذُ بِهَؤُلاَءِ الْكَلِمَاتِ كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْكَسَلِ وَالْهَرَمِ وَالْجُبْنِ وَالْبُخْلِ وَسُوءِ الْكِبَرِ وَفِتْنَةِ الدَّجَّالِ وَعَذَابِ الْقَبْرِ ‏"‏ ‏.‏\hadithno{5495}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah [SAW] used to seek refuge by saying these words: 'Allahumma inni a'udhu bika minal-kasali, wal-harami, wal-jubni, wal-bukhli, wa suw'il-kibari, wa fitnatid-dajjali wa 'adhabil-qabr (O Allah, I seek refuge with You from laziness, old age, cowardice, miserliness, a bad old age, the tribulation of the Dajjal and the torment of the grave)}}
\hadithdefcmd{nasai}{5496}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، قَالَ سَمِعْتُ مُصْعَبَ بْنَ سَعْدٍ، عَنْ أَبِيهِ، قَالَ كَانَ يُعَلِّمُنَا خَمْسًا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْعُو بِهِنَّ وَيَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْبُخْلِ وَأَعُوذُ بِكَ مِنَ الْجُبْنِ وَأَعُوذُ بِكَ مِنْ أَنْ أُرَدَّ إِلَى أَرْذَلِ الْعُمُرِ وَأَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ ‏"‏ ‏.‏\hadithno{5496}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdul-Malik bin 'Umair said:"I heard Mus'ab bin Sa'd say, concerning his father: 'He used to teach us five things that the Messenger of Allah [SAW] used to recite in his supplication, and say: "Allahumma inni a'udhu bika minal-bukhli, wa a'udhu bika minal-jubni, wa a'udhu bika an uradda ila ardhalil-'umuri, wa a'udhu bika min 'adhabil-qabr (O Allah, I seek refuge in You from miserliness, and I seek refuge in You from cowardice, and I seek refuge in You from reaching the age of senility, and I seek refuge in You from the torment of the grave)}}
\hadithdefcmd{nasai}{5497}{أَخْبَرَنَا عِمْرَانُ بْنُ بَكَّارٍ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا يُونُسُ، عَنْ أَبِي إِسْحَاقَ، - يَعْنِي أَبَاهُ - عَنْ عَمْرِو بْنِ مَيْمُونٍ، قَالَ حَجَجْتُ مَعَ عُمَرَ فَسَمِعْتُهُ يَقُولُ بِجَمْعٍ أَلاَ إِنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَتَعَوَّذُ مِنْ خَمْسٍ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْبُخْلِ وَالْجُبْنِ وَأَعُوذُ بِكَ مِنْ سُوءِ الْعُمُرِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الصَّدْرِ وَأَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ ‏"‏ ‏.‏\hadithno{5497}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Amr bin Maimun said:"I went for Hajj with 'Umar, and in Muzdalifah, I heard him say that the Prophet [SAW] used to seek refuge from five things: 'Allahumma inni a'udhu bika minal-bukhli, wal-jubni, wa a'udhu bika min su'il-'umuri, wa a'udhu bika min fitnatis-sadri, wa a'udhu bika min 'adhabil-qabr (O Allah, I seek refuge with You from miserliness and cowardice, and I seek refuge with You from reaching the age of second childhood, and I seek refuge in You from the ills of the heart, and I seek refuge in You from the torment of the grave)}}
\hadithdefcmd{nasai}{5498}{أَخْبَرَنَا أَزْهَرُ بْنُ جَمِيلٍ، قَالَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ سَرْجِسَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا سَافَرَ قَالَ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ وَعْثَاءِ السَّفَرِ وَكَآبَةِ الْمُنْقَلَبِ وَالْحَوْرِ بَعْدَ الْكَوْرِ وَدَعْوَةِ الْمَظْلُومِ وَسُوءِ الْمَنْظَرِ فِي الأَهْلِ وَالْمَالِ ‏"‏ ‏.‏\hadithno{5498}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin Sarjis that :When the Messenger of Allah [SAW] traveled, he would say: "Allahumma inni a'udhu bika min wa'tha'is-safari, wa kabatil-munqalabi, wal-hawri ba'dal-kawri, wa da'watil-mazlumi, wa suw'il-munzari fil-ahli wal-mal (O Allah, I seek refuge with You from the hardships of travel and the sorrows of return, from loss after plenty, from the supplication of the one who has been wronged, and seeing some calamity befall my family or wealth)}}
\hadithdefcmd{nasai}{5499}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ عَاصِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ سَرْجِسَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا سَافَرَ قَالَ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ وَعْثَاءِ السَّفَرِ وَكَآبَةِ الْمُنْقَلَبِ وَالْحَوْرِ بَعْدَ الْكَوْرِ وَدَعْوَةِ الْمَظْلُومِ وَسُوءِ الْمَنْظَرِ فِي الأَهْلِ وَالْمَالِ وَالْوَلَدِ ‏"‏ ‏.‏\hadithno{5499}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin Sarjis that :When the Messenger of Allah [SAW] traveled, he would say: "Allahumma inni a'udhu bika min wa'tha'is-safari, wa kabatil-munqalabi, wal-hawri ba'dal-kawri, wa da'watil-mazlumi, wa su'il-munzari fil-ahli wal-mali wal-walad (O Allah, I seek refuge with You from the hardships of travel and the sorrows of return, from loss after plenty, from the supplication of the one who has been wronged, and seeing some calamity befall my family or wealth or child)}}
\hadithdefcmd{nasai}{5500}{أَخْبَرَنَا يُوسُفُ بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا بِشْرُ بْنُ مَنْصُورٍ، عَنْ عَاصِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ سَرْجِسَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا سَافَرَ يَتَعَوَّذُ مِنْ وَعْثَاءِ السَّفَرِ وَكَآبَةِ الْمُنْقَلَبِ وَالْحَوْرِ بَعْدَ الْكَوْرِ وَدَعْوَةِ الْمَظْلُومِ وَسُوءِ الْمَنْظَرِ ‏.‏\hadithno{5500}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin Sarjis said:"When the Prophet [SAW] traveled, he would seek refuge with Allah from the hardships of travel, and the sorrows of return, from loss after plenty, from the supplication of the one who has been wronged, and from seeing some calamity befall}}
\hadithdefcmd{nasai}{5501}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ عَلِيِّ بْنِ مُقَدَّمٍ، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ بِشْرٍ الْخَثْعَمِيِّ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا سَافَرَ فَرَكِبَ رَاحِلَتَهُ قَالَ بِإِصْبَعِهِ - وَمَدَّ شُعْبَةُ بِإِصْبَعِهِ - قَالَ ‏ "‏ اللَّهُمَّ أَنْتَ الصَّاحِبُ فِي السَّفَرِ وَالْخَلِيفَةُ فِي الأَهْلِ وَالْمَالِ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ وَعْثَاءِ السَّفَرِ وَكَآبَةِ الْمُنْقَلَبِ ‏"‏ ‏.‏\hadithno{5501}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"When the Messenger of Allah [SAW] traveled and rode his mount, he gestured with his finger - and Shu'bah (one of the narrators) stretched out his finger - and said: 'Allahumma, antas-sahibu fis-safari wal-khalifatu fil-ahli wal-mal. Allahumma, inni a'udhu bika min wa'tha'is-safari, wa kabatil-munqalabi (O Allah, You are our help when we are traveling and the One Who takes care of our families and wealth (in our absence). O Allah, I seek refuge in You from the hardships of travel and the sorrows of return}}
\hadithdefcmd{nasai}{5502}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَجْلاَنَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَعَوَّذُوا بِاللَّهِ مِنْ جَارِ السَّوْءِ فِي دَارِ الْمُقَامِ فَإِنَّ جَارَ الْبَادِيَةِ يَتَحَوَّلُ عَنْكَ ‏"‏ ‏.‏\hadithno{5502}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] said: 'Seek refuge with Allah from a bad neighbor in one's permanent abode, for one's neighbor in the desert will change}}
\hadithdefcmd{nasai}{5503}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا عَمْرُو بْنُ أَبِي عَمْرٍو، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَبِي طَلْحَةَ ‏"‏ الْتَمِسْ لِي غُلاَمًا مِنْ غِلْمَانِكُمْ يَخْدُمُنِي ‏"‏ ‏.‏ فَخَرَجَ بِي أَبُو طَلْحَةَ يَرْدُفُنِي وَرَاءَهُ فَكُنْتُ أَخْدُمُ رَسُولَ اللَّهِ صلى الله عليه وسلم كُلَّمَا نَزَلَ فَكُنْتُ أَسْمَعُهُ يُكْثِرُ أَنْ يَقُولَ ‏"‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْهَرَمِ وَالْحُزْنِ وَالْعَجْزِ وَالْكَسَلِ وَالْبُخْلِ وَالْجُبْنِ وَضَلَعِ الدَّيْنِ وَغَلَبَةِ الرِّجَالِ ‏"‏ ‏.‏\hadithno{5503}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Anas bin Malik said:"The Messenger of Allah [SAW] said to Abu Talhah: 'Find me one of your boys to serve me.' Abu Talhah brought me out, riding behind him, and I served the Prophet [SAW] every time he stopped (on his journey). And I often heard him say: 'Allahumma, inni a'udhu bika min al-harami, wal-huzni, wal-'ajzi, wal-kasali, wal-bukhli, wal-jubni, wa dala'id-dain, wa ghalabatir-rijal (O Allah, I seek refuge in You from old age, grief, incapacity, laziness, miserliness, cowardice, the burden of debt and being overpowered by men)}}
\hadithdefcmd{nasai}{5504}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ يَحْيَى، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَسْتَعِيذُ بِاللَّهِ مِنْ عَذَابِ الْقَبْرِ وَمِنْ فِتْنَةِ الدَّجَّالِ قَالَ وَقَالَ ‏ "‏ إِنَّكُمْ تُفْتَنُونَ فِي قُبُورِكُمْ ‏"‏ ‏.‏\hadithno{5504}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Aishah that:The Prophet [SAW] used to seek refuge with Allah from the torment of the grave and the tribulation of the Dajjal, and he said: "You will be tried in your graves}}
\hadithdefcmd{nasai}{5505}{أَخْبَرَنَا أَحْمَدُ بْنُ حَفْصِ بْنِ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي إِبْرَاهِيمُ، عَنْ مُوسَى بْنِ عُقْبَةَ، أَخْبَرَنِي أَبُو الزِّنَادِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَعُوذُ بِاللَّهِ مِنْ عَذَابِ جَهَنَّمَ وَأَعُوذُ بِاللَّهِ مِنْ عَذَابِ الْقَبْرِ وَأَعُوذُ بِاللَّهِ مِنْ شَرِّ الْمَسِيحِ الدَّجَّالِ وَأَعُوذُ بِاللَّهِ مِنْ شَرِّ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏ ‏.‏\hadithno{5505}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] said: "A'udhu billahi min 'adhabi jahannama, wa a'udhu billahi min 'adhabil-qabri, wa a'udhu billahi min sharril-masihid-dajjali, wa a'udhu billahi min sharri fitnatil-mahya wal-mamat (I seek refuge with Allah from the torment of Hell, and I seek refuge with Allah from the torment of the grave, and I seek refuge with Allah from the evil of the Dajjal, and I seek refuge with Allah from the evil of the trials of life and death)}}
\hadithdefcmd{nasai}{5506}{أَخْبَرَنَا يَحْيَى بْنُ دُرُسْتَ، قَالَ حَدَّثَنَا أَبُو إِسْمَاعِيلَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، أَنَّ أَبَا سَلَمَةَ، حَدَّثَهُ عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ وَأَعُوذُ بِكَ مِنْ عَذَابِ النَّارِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ وَأَعُوذُ بِكَ مِنْ شَرِّ الْمَسِيحِ الدَّجَّالِ ‏"‏ ‏.‏\hadithno{5506}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah [SAW] used to say: "Allahumma inni a'udhu bika min 'adhabil-qabri, wa a'udhu bika min 'adhabin-nari, wa a'udhu bika min fitnatil-mahya wal-mamat wa a'udhu bika min sharril-masihid-dajjali (O Allah, I seek refuge with You from the torment of the grave, and I seek refuge with You from the torment of the Fire, and I seek refuge with You from the trials of life and death, and I seek refuge with You from the evil of the Al-Masihid-Dajjal)}}
\hadithdefcmd{nasai}{5507}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ عَوْنٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِي عُمَرَ، عَنْ عُبَيْدِ بْنِ خَشْخَاشٍ، عَنْ أَبِي ذَرٍّ، قَالَ دَخَلْتُ الْمَسْجِدَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم فِيهِ فَجِئْتُ فَجَلَسْتُ إِلَيْهِ فَقَالَ ‏"‏ يَا أَبَا ذَرٍّ تَعَوَّذْ بِاللَّهِ مِنْ شَرِّ شَيَاطِينِ الْجِنِّ وَالإِنْسِ ‏"‏ ‏.‏ قُلْتُ أَوَلِلإِنْسِ شَيَاطِينُ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏\hadithno{5507}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Dharr said:"I entered the Masjid and the Messenger of Allah [SAW] was there, so I came and sat before him and he said: 'O Abu Dharr, seek refuge with Allah from the evils of the devils among the Jinn and mankind.' I said: 'Are there devils among mankind?' He said: 'Yes}}
\hadithdefcmd{nasai}{5508}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، وَمَالِكٌ، قَالاَ حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ عُوذُوا بِاللَّهِ مِنْ عَذَابِ الْقَبْرِ عُوذُوا بِاللَّهِ مِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ عُوذُوا بِاللَّهِ مِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ ‏"‏ ‏.‏\hadithno{5508}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet [SAW] said: "Seek refuge with Allah from the torment of the grave, seek refuge with Allah from the trials of life and death, and seek refuge with Allah from the tribulation of Al-Masihid-Dajjal}}
\hadithdefcmd{nasai}{5509}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي يَعْلَى بْنُ عَطَاءٍ، قَالَ سَمِعْتُ أَبَا عَلْقَمَةَ، يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَتَعَوَّذُ مِنْ خَمْسٍ يَقُولُ ‏ "‏ عُوذُوا بِاللَّهِ مِنْ عَذَابِ الْقَبْرِ وَمِنْ عَذَابِ جَهَنَّمَ وَمِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ وَمِنْ شَرِّ الْمَسِيحِ الدَّجَّالِ ‏"‏ ‏.‏\hadithno{5509}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah [SAW] used to seek refuge with Allah from five things, saying: "Seek refuge with Allah from the torment of the grave, and from the torment of Hell, and from the trials of life and death, and from the evil of Al-Masihid-Dajjal}}
\hadithdefcmd{nasai}{5510}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، عَنْ مُحَمَّدٍ، وَذَكَرَ، كَلِمَةً مَعْنَاهَا حَدَّثَنَا شُعْبَةُ، عَنْ يَعْلَى بْنِ عَطَاءٍ، قَالَ سَمِعْتُ أَبَا عَلْقَمَةَ الْهَاشِمِيَّ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ أَطَاعَنِي فَقَدْ أَطَاعَ اللَّهَ وَمَنْ عَصَانِي فَقَدْ عَصَى اللَّهَ ‏"‏ ‏.‏ وَكَانَ يَتَعَوَّذُ مِنْ عَذَابِ الْقَبْرِ وَعَذَابِ جَهَنَّمَ وَفِتْنَةِ الأَحْيَاءِ وَالأَمْوَاتِ وَفِتْنَةِ الْمَسِيحِ الدَّجَّالِ ‏.‏\hadithno{5510}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah said:"I heard the Messenger of Allah [SAW] say: 'Whoever obeys me has obeyed Allah and whoever disobeys me has disobeyed Allah.' And he used to seek refuge from the torment of the grave, the torment of Hell, the trials that may befall the living and the dead, and the tribulation of Al-Masihid-Dajjal}}
\hadithdefcmd{nasai}{5511}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا أَبُو الْوَلِيدِ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ أَبِيهِ، عَنْ أَبِي عَلْقَمَةَ، حَدَّثَنِي أَبُو هُرَيْرَةَ، مِنْ فِيهِ إِلَى فِيَّ قَالَ وَقَالَ يَعْنِي النَّبِيَّ صلى الله عليه وسلم ‏ "‏ اسْتَعِيذُوا بِاللَّهِ مِنْ خَمْسٍ مِنْ عَذَابِ جَهَنَّمَ وَعَذَابِ الْقَبْرِ وَفِتْنَةِ الْمَحْيَا وَالْمَمَاتِ وَفِتْنَةِ الْمَسِيحِ الدَّجَّالِ ‏"‏ ‏.‏\hadithno{5511}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah said:"He (meaning the Prophet [SAW]) said: 'Seek refuge with Allah from five things: From the torment of Hell, the torment of the grave, the trials of life and death, and the tribulation of Al-Masihid-Dajjal}}
\hadithdefcmd{nasai}{5512}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ طَاوُسٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُعَلِّمُهُمْ هَذَا الدُّعَاءَ كَمَا يُعَلِّمُ السُّورَةَ مِنَ الْقُرْآنِ ‏ "‏ قُولُوا اللَّهُمَّ إِنَّا نَعُوذُ بِكَ مِنْ عَذَابِ جَهَنَّمَ وَأَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏ ‏.‏\hadithno{5512}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin 'Abbas that:The Messenger of Allah [SAW] used to teach them this supplication as he would teach them a Surah of the Qur'an: "Say: 'Allahumma, inni na'uwdhu bika min 'adhabi jahannama, wa a'udhu bika min 'adhabil-qabri, wa a'udhu bika min fitnatil-masihid-dajjali, wa a'udhu bika min fitnatil-mahya wal-mamat (O Allah, we seek refuge with You from the torment of Hell, and I seek refuge with You from the torment of the grave, and I seek refuge with You from the tribulation of Al-Masihid-Dajjal, and I seek refuge with You from the trials of life and death)}}
\hadithdefcmd{nasai}{5513}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَيْمُونٍ، عَنْ سُفْيَانَ، عَنْ عَمْرٍو، عَنْ طَاوُسٍ، عَنْ أَبِي هُرَيْرَةَ، وَأَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ عُوذُوا بِاللَّهِ عَزَّ وَجَلَّ مِنْ عَذَابِ اللَّهِ عُوذُوا بِاللَّهِ مِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ وَمِنْ عَذَابِ الْقَبْرِ وَمِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ ‏"‏ ‏.‏\hadithno{5513}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet [SAW] said: "Seek refuge with Allah from the punishment of Allah, seek refuge with Allah from the trials of life and death, from the torment of the grave and from the tribulation of the Al-Masihid-Dajjal}}
\hadithdefcmd{nasai}{5514}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَدْعُو يَقُولُ فِي دُعَائِهِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عَذَابِ جَهَنَّمَ وَأَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏ ‏.‏\hadithno{5514}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah [SAW] used to say in his supplication: "Allahumma, inni a'udhu bika min 'adhabi jahannama, wa a'udhu bika min 'adhabil-qabri, wa a'udhu bika min fitnatil-masihid-dajjali, wa a'udhu bika min fitnatil-mahya wal-mamat (O Allah, I seek refuge with You from the torment of Hell, and I seek refuge in You from the torment of the grave, and I seek refuge in You from the tribulation of the Al-Masihid-Dajjal, and I seek refuge with You from the trials of life and death)}}
\hadithdefcmd{nasai}{5515}{أَخْبَرَنَا أَبُو عَاصِمٍ، قَالَ حَدَّثَنَا الْقَاسِمُ بْنُ كَثِيرٍ الْمُقْرِئُ، عَنِ اللَّيْثِ بْنِ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي دُعَائِهِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ فِتْنَةِ الْقَبْرِ وَفِتْنَةِ الدَّجَّالِ وَفِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا خَطَأٌ وَالصَّوَابُ سُلَيْمَانُ بْنُ سِنَانٍ ‏.‏\hadithno{5515}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Sulaiman bin Yasar that he heard Abu Hurairah say:"I heard the Messenger of Allah [SAW] say in his supplication: 'Allahumma, inni a'udhu bika min fitnatil-qabri, wa fitnatid-dajjali, wa fitnatil-mahya wal-mamat (O Allah, I seek refuge with You from the trial of the grave, and the tribulation of the Dajjal, and the trials of life and death)}}
\hadithdefcmd{nasai}{5516}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ عُوذُوا بِاللَّهِ مِنْ عَذَابِ اللَّهِ عُوذُوا بِاللَّهِ مِنْ عَذَابِ الْقَبْرِ عُوذُوا بِاللَّهِ مِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ عُوذُوا بِاللَّهِ مِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ ‏"‏ ‏.‏\hadithno{5516}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that :The Prophet [SAW] said: "Seek refuge with Allah from the punishment of Allah, seek refuge with Allah from the torment of the grave, seek refuge with Allah from the trials of life and death, and seek refuge with Allah from the tribulation of Al-Masihid-Dajjal}}
\hadithdefcmd{nasai}{5517}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ بُدَيْلِ بْنِ مَيْسَرَةَ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَعَوَّذُ مِنْ عَذَابِ جَهَنَّمَ وَعَذَابِ الْقَبْرِ وَالْمَسِيحِ الدَّجَّالِ ‏.‏\hadithno{5517}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] used to seek refuge (with Allah) from the torment of Hell, the torment of the grave, and Al-Masihid-Dajjal}}
\hadithdefcmd{nasai}{5518}{أَخْبَرَنَا مَحْمُودُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا الْوَلِيدُ، قَالَ حَدَّثَنَا أَبُو عَمْرٍو، عَنْ يَحْيَى، أَنَّهُ حَدَّثَهُ قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ، قَالَ حَدَّثَنِي أَبُو هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَعَوَّذُوا بِاللَّهِ مِنْ عَذَابِ النَّارِ وَعَذَابِ الْقَبْرِ وَمِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ وَمِنْ شَرِّ الْمَسِيحِ الدَّجَّالِ ‏"‏ ‏.‏\hadithno{5518}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah said:The Messenger of Allah [SAW] said: "Seek refuge with Allah from the torment of the Fire and the torment of the grave, from the trials of life and death, and from the evil of Al-Masihid-Dajjal}}
\hadithdefcmd{nasai}{5519}{أَخْبَرَنَا أَحْمَدُ بْنُ حَفْصٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي إِبْرَاهِيمُ، عَنْ سُفْيَانَ بْنِ سَعِيدٍ، عَنْ أَبِي حَسَّانَ، عَنْ جَسْرَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ رَبَّ جِبْرَائِيلَ وَمِيكَائِيلَ وَرَبَّ إِسْرَافِيلَ أَعُوذُ بِكَ مِنْ حَرِّ النَّارِ وَمِنْ عَذَابِ الْقَبْرِ ‏"‏ ‏.‏\hadithno{5519}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah [SAW] said: 'Allahumma, rabba jibra'ila, wa mika'ila wa rabba israfila, a'udhu bika min harrin-nari wa (min) 'adhabil-qabr (O Allah, Lord of Jibra'il and Mika'il and Lord of Israfil, I seek refuge in You from the heat of the Fire and (from) the torment of the grave}}
\hadithdefcmd{nasai}{5520}{أَخْبَرَنَا عَمْرُو بْنُ سَوَّادٍ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ حَدَّثَنَا عَمْرُو بْنُ الْحَارِثِ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سُلَيْمَانَ بْنِ سِنَانٍ الْمُزَنِيِّ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ سَمِعْتُ أَبَا الْقَاسِمِ، صلى الله عليه وسلم يَقُولُ فِي صَلاَتِهِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ فِتْنَةِ الْقَبْرِ وَمِنْ فِتْنَةِ الدَّجَّالِ وَمِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ وَمِنْ حَرِّ جَهَنَّمَ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا الصَّوَابُ ‏.‏\hadithno{5520}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Sulaiman bin Sinan Al-Muzani that he heard Abu Hurairah say:"I heard Abu Al-Qasim [SAW] say, during his prayer: 'Allahumma, inni a'udhu bika min fitnatil-qabri, wa fitnatid-dajjali, wa min fitnatil-mahya wal-mamati, wa min harri jahannam (O Allah, I seek refuge with You from the trial of the grave, and from the tribulation of the Dajjal, and from the trials of life and death, and from the heat of Hell)}}
\hadithdefcmd{nasai}{5521}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ بُرَيْدِ بْنِ أَبِي مَرْيَمَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ سَأَلَ اللَّهَ الْجَنَّةَ ثَلاَثَ مَرَّاتٍ قَالَتِ الْجَنَّةُ اللَّهُمَّ أَدْخِلْهُ الْجَنَّةَ وَمَنِ اسْتَجَارَ مِنَ النَّارِ ثَلاَثَ مَرَّاتٍ قَالَتِ النَّارُ اللَّهُمَّ أَجِرْهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{5521}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah [SAW] said: 'Whoever asks Allah for Paradise three times, Paradise will say: 'O Allah, admit him to Paradise.' And whoever seeks protection from Hell three times, Hell will say: 'O Allah, protect him from the Fire}}
\hadithdefcmd{nasai}{5522}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ بُشَيْرِ بْنِ كَعْبٍ، عَنْ شَدَّادِ بْنِ أَوْسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ سَيِّدَ الاِسْتِغْفَارِ أَنْ يَقُولَ الْعَبْدُ اللَّهُمَّ أَنْتَ رَبِّي لاَ إِلَهَ إِلاَّ أَنْتَ خَلَقْتَنِي وَأَنَا عَبْدُكَ وَأَنَا عَلَى عَهْدِكَ وَوَعْدِكَ مَا اسْتَطَعْتُ أَعُوذُ بِكَ مِنْ شَرِّ مَا صَنَعْتُ أَبُوءُ لَكَ بِذَنْبِي وَأَبُوءُ لَكَ بِنِعْمَتِكَ عَلَىَّ فَاغْفِرْ لِي فَإِنَّهُ لاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ فَإِنْ قَالَهَا حِينَ يُصْبِحُ مُوقِنًا بِهَا فَمَاتَ دَخَلَ الْجَنَّةَ وَإِنْ قَالَهَا حِينَ يُمْسِي مُوقِنًا بِهَا دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏ خَالَفَهُ الْوَلِيدُ بْنُ ثَعْلَبَةَ ‏.‏\hadithno{5522}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Shaddad bin Aws that :The Prophet [SAW] said: "The best of prayers for forgiveness is for a person to say: 'Allahumma, anta rabbi, la ilaha illa anta, khalaqtani wa ana 'abduka, wa ana 'ala 'ahdika wa wa'dika mastata'tu, a'udhu bika min sharri ma sana'tu, abuw'u laka bidhanbi, wa abuw'u laka bini'matika 'alayya faghfirli, fa innahu la yaghfirudh-dhunuba illa anta (O Allah, You are my Lord, there is no god but You. You have created me and I am Your slave and I am keeping my promise and covenant to You as much as I can. I seek refuge with You from the evil of what I do. I acknowledge Your blessing and I acknowledge my sin, so forgive me, for there is none who can forgive sin except You.)' If he says this in the morning, believing in it firmly, and dies on that day before evening comes, he will enter Paradise, and if he says it in the evening, believing firmly in it, and dies before morning comes, he will enter Paradise." Al-Walid bin Tha'labah contradicted him}}
\hadithdefcmd{nasai}{5523}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي مُوسَى بْنُ شَيْبَةَ، عَنِ الأَوْزَاعِيِّ، عَنْ عَبْدَةَ بْنِ أَبِي لُبَابَةَ، أَنَّ ابْنَ يِسَافٍ، حَدَّثَهُ أَنَّهُ، سَأَلَ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم مَا كَانَ أَكْثَرَ مَا يَدْعُو بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم قَبْلَ مَوْتِهِ قَالَتْ كَانَ أَكْثَرَ مَا كَانَ يَدْعُو بِهِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ شَرِّ مَا عَمِلْتُ وَمِنْ شَرِّ مَا لَمْ أَعْمَلْ ‏"‏ ‏.‏\hadithno{5523}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdah bin Abi Lubabah that Ibn Yasaf told him that he asked 'Aishah, the wife of the Prophet [SAW], :What supplication did the Messenger of Allah [SAW] say the most before he died? She said: "The supplication that he said the most was: 'Allahumma, inni a'udhu bika min sharri ma 'amiltu wa min sharri ma lam a'mal ba'd (O Allah, I seek refuge with You from the evil of what I have done, and from the evil of what I have not done yet)}}
\hadithdefcmd{nasai}{5524}{أَخْبَرَنِي عِمْرَانُ بْنُ بَكَّارٍ، قَالَ حَدَّثَنَا أَبُو الْمُغِيرَةِ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي عَبْدَةُ، قَالَ حَدَّثَنِي ابْنُ يِسَافٍ، قَالَ سُئِلَتْ عَائِشَةُ مَا كَانَ أَكْثَرَ مَا كَانَ يَدْعُو بِهِ النَّبِيُّ صلى الله عليه وسلم قَالَتْ كَانَ أَكْثَرَ دُعَائِهِ أَنْ يَقُولَ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ شَرِّ مَا عَمِلْتُ وَمِنْ شَرِّ مَا لَمْ أَعْمَلْ بَعْدُ ‏"‏ ‏.‏\hadithno{5524}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Yasaf said:"I asked 'Aishah, what was the supplication that the Prophet [SAW] said the most? She said: 'The supplication that he said the most was: Allahumma, inni a'udhu bika min sharri ma 'amiltu wa min sharri ma lam a'mal ba'd (O Allah, I seek refuge with You from the evil of what I have done, and from the evil of what I have not done yet)}}
\hadithdefcmd{nasai}{5525}{أَخْبَرَنِي مُحَمَّدُ بْنُ قُدَامَةَ، عَنْ جَرِيرٍ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ فَرْوَةَ بْنِ نَوْفَلٍ، قَالَ سَأَلْتُ أُمَّ الْمُؤْمِنِينَ عَائِشَةَ عَمَّا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْعُو قَالَتْ كَانَ يَقُولُ ‏ "‏ أَعُوذُ بِكَ مِنْ شَرِّ مَا عَمِلْتُ وَمِنْ شَرِّ مَا لَمْ أَعْمَلْ ‏"‏ ‏.‏\hadithno{5525}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Farwah bin Nawfal said:"I asked the Mother of the Believers 'Aishah about what the Messenger of Allah [SAW] used to say in his supplication. She said: 'He used to say: A'udhu bika min sharri ma 'amiltu wa min sharri ma lam a'mal ba'd (I seek refuge with You from the evil of what I have done and the evil of what I have not done yet)}}
\hadithdefcmd{nasai}{5526}{أَخْبَرَنَا هَنَّادٌ، عَنْ أَبِي الأَحْوَصِ، عَنْ حُصَيْنٍ، عَنْ هِلاَلٍ، عَنْ فَرْوَةَ بْنِ نَوْفَلٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَ عُوذُ بِكَ مِنْ شَرِّ مَا عَمِلْتُ وَمِنْ شَرِّ مَا لَمْ أَعْمَلْ ‏"‏ ‏.‏\hadithno{5526}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah [SAW] used to say: 'Allahumma, inni a'udhu bika min sharri ma 'amiltu wa min sharri ma lam a'mal ba'd (O Allah, I seek refuge with You from the evil of what I have done and from the evil of what I have not done yet)}}
\hadithdefcmd{nasai}{5527}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، عَنْ أَبِيهِ، عَنْ حُصَيْنٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ فَرْوَةَ بْنِ نَوْفَلٍ، قَالَ سَأَلْتُ عَائِشَةَ فَقُلْتُ حَدِّثِينِي بِشَىْءٍ، كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْعُو بِهِ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ شَرِّ مَا عَمِلْتُ وَمِنْ شَرِّ مَا لَمْ أَعْمَلْ ‏"‏ ‏.‏\hadithno{5527}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Farwah bin Nawfal said:"I asked 'Aishah: 'Tell me of something that the Messenger of Allah [SAW] used to say in his supplication.' She said: 'The Messenger of Allah [SAW] used to say: Allahumma, inni a'udhu bika min sharri ma 'amiltu wa min sharri ma lam a'mal ba'd (O Allah, I seek refuge with You from the evil of what I have done and from the evil of what I have not done)}}
\hadithdefcmd{nasai}{5528}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ حُصَيْنٍ، سَمِعْتُ هِلاَلَ بْنَ يِسَافٍ، عَنْ فَرْوَةَ بْنِ نَوْفَلٍ، قَالَ قُلْتُ لِعَائِشَةَ أَخْبِرِينِي بِدُعَاءٍ، كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْعُو بِهِ ‏.‏ قَالَتْ كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ شَرِّ مَا عَمِلْتُ وَمِنْ شَرِّ مَا لَمْ أَعْمَلْ ‏"‏ ‏.‏\hadithno{5528}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Farwah bin Nawfal said:"I said to 'Aishah: 'Tell me of a supplication that the Messenger of Allah [SAW] used to say.' She said: 'He used to say: Allahumma, inni a'udhu bika min sharri ma 'amiltu wa min sharri ma lam a'mal ba'd (O Allah, I seek refuge in You from the evil of what I have done and from the evil of what I have not done)}}
\hadithdefcmd{nasai}{5529}{حَدَّثَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، عَنْ عُبَادَةَ بْنِ مُسْلِمٍ، قَالَ حَدَّثَنِي جُبَيْرُ بْنُ أَبِي سُلَيْمَانَ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، أَنَّ ابْنَ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِعَظَمَتِكَ أَنْ أُغْتَالَ مِنْ تَحْتِي ‏"‏ ‏.‏ قَالَ جُبَيْرٌ وَهُوَ الْخَسْفُ ‏.‏ قَالَ عُبَادَةُ فَلاَ أَدْرِي قَوْلَ النَّبِيِّ صلى الله عليه وسلم أَوْ قَوْلَ جُبَيْرٍ ‏.‏\hadithno{5529}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Umar said:"I heard the Messenger of Allah [SAW] say: 'Allahumma, inni a'udhu bi-'azamatika an ughtala min tahti (O Allah, I seek refuge in Your greatness from being swallowed up from beneath me)}}
\hadithdefcmd{nasai}{5530}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْخَلِيلِ، قَالَ حَدَّثَنَا مَرْوَانُ، - هُوَ ابْنُ مُعَاوِيَةَ - عَنْ عَلِيِّ بْنِ عَبْدِ الْعَزِيزِ، عَنْ عُبَادَةَ بْنِ مُسْلِمٍ الْفَزَارِيِّ، عَنْ جُبَيْرِ بْنِ أَبِي سُلَيْمَانَ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏"‏ اللَّهُمَّ ‏"‏ ‏.‏ فَذَكَرَ الدُّعَاءَ وَقَالَ فِي آخِرِهِ ‏"‏ أَعُوذُ بِكَ أَنْ أُغْتَالَ مِنْ تَحْتِي ‏"‏ ‏.‏ يَعْنِي بِذَلِكَ الْخَسْفَ ‏.‏\hadithno{5530}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"The Prophet [SAW] used to say: 'Allahumma (O Allah,)' and he mentioned the supplication, and said at the end, 'A'udhu bika an ughtala min tahti (and I seek refuge with You from being swallowed up from beneath me)}}
\hadithdefcmd{nasai}{5531}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدٍ، عَنْ صَيْفِيٍّ، مَوْلَى أَبِي أَيُّوبَ عَنْ أَبِي الْيَسَرِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ التَّرَدِّي وَالْهَدْمِ وَالْغَرَقِ وَالْحَرِيقِ وَأَعُوذُ بِكَ أَنْ يَتَخَبَّطَنِي الشَّيْطَانُ عِنْدَ الْمَوْتِ وَأَعُوذُ بِكَ أَنْ أَمُوتَ فِي سَبِيلِكَ مُدْبِرًا وَأَعُوذُ بِكَ أَنْ أَمُوتَ لَدِيغًا ‏"‏ ‏.‏\hadithno{5531}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Al-Yasar said:"The Messenger of Allah [SAW] used to say: 'Allahumma inni a'udhu bika minat-taraddi, wal-hadmi, wal-gharaqi, wal-hariqi, wa a'udhu bika, an yatakhabbatanish-shaitanu 'indal-mawti, wa a'udhu bika an amuta fi sabilika mudbiran, wa a'udhu bika an amuta ladigha (O Allah, I seek refuge with You from being thrown from a high place or crushed beneath a falling wall, or drowning or being burned, and I seek refuge with You from being led astray by the Shaitan at the time of death, and I seek refuge with You from dying in Your cause while fleeing from the battlefield, and I seek refuge with You from dying of a scorpion sting)}}
\hadithdefcmd{nasai}{5532}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ أَخْبَرَنِي أَنَسُ بْنُ عِيَاضٍ، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدٍ، عَنْ صَيْفِيٍّ، عَنْ أَبِي الْيَسَرِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَدْعُو فَيَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْهَرَمِ وَالتَّرَدِّي وَالْهَدْمِ وَالْغَمِّ وَالْحَرِيقِ وَالْغَرَقِ وَأَعُوذُ بِكَ أَنْ يَتَخَبَّطَنِي الشَّيْطَانُ عِنْدَ الْمَوْتِ وَأَنْ أُقْتَلَ فِي سَبِيلِكَ مُدْبِرًا وَأَعُوذُ بِكَ أَنْ أَمُوتَ لَدِيغًا ‏"‏ ‏.‏\hadithno{5532}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Al-Yasar that :The Messenger of Allah [SAW] used to supplicate and say: "Allahumma inni a'udhu bika min al-harami, wat-taraddi, wal-hadmi, wal-ghammi, wal-hariqi, wal-gharaqi, wa a'udhu bika, an yatakhabbatanish-shaitanu 'indal-mawti, wa an uqtala fi sabilika mudbiran, wa a'udhu bika wa an amuta ladigha (O Allah, I seek refuge with You from old age, being thrown from a high place, being crushed by a falling wall, distress, burning and drowning. I seek refuge with You from being led astray by the Shaitan at the time of death and from being killed in Your cause while fleeing from the battlefield. I seek refuge with You from dying of a scorpion sting)}}
\hadithdefcmd{nasai}{5533}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنِي صَيْفِيٌّ، مَوْلَى أَبِي أَيُّوبَ الأَنْصَارِيُّ عَنْ أَبِي الأَسْوَدِ السُّلَمِيِّ، هَكَذَا قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْهَدْمِ وَأَعُوذُ بِكَ مِنَ التَّرَدِّي وَأَعُوذُ بِكَ مِنَ الْغَرَقِ وَالْحَرِيقِ وَأَعُوذُ بِكَ أَنْ يَتَخَبَّطَنِي الشَّيْطَانُ عِنْدَ الْمَوْتِ وَأَعُوذُ بِكَ أَنْ أَمُوتَ فِي سَبِيلِكَ مُدْبِرًا وَأَعُوذُ بِكَ أَنْ أَمُوتَ لَدِيغًا ‏"‏ ‏.‏\hadithno{5533}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Al-Aswad Al-Sulami said:"The Messenger of Allah [SAW] used to say: 'Allahumma inni a'udhu bika minal-hadmi, wa a'udhu bika minat-taraddi, wa a'udhu bika minal-gharaqi, wal-hariqi, wa a'udhu bika an yatakhabbatanish-shaitanu 'indal-mawti, wa a'udhu bika an amuta fi sabilika mudbiran, wa a'udhu bika an amuta ladigha (O Allah, I seek refuge in You from being crushed by a falling wall, and I seek refuge with You from drowning or being burned, and I seek refuge with You from being led astray by the Shaitan at the time of death, and I seek refuge with You from being killed for Your sake while fleeing the battlefield, and I seek refuge with You from dying of a scorpion sting)}}
\hadithdefcmd{nasai}{5534}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنِي الْعَلاَءُ بْنُ هِلاَلٍ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ زَيْدٍ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنِ الْقَاسِمِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ مَسْرُوقِ بْنِ الأَجْدَعِ، عَنْ عَائِشَةَ، قَالَتْ طَلَبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فِي فِرَاشِي فَلَمْ أُصِبْهُ فَضَرَبْتُ بِيَدِي عَلَى رَأْسِ الْفِرَاشِ فَوَقَعَتْ يَدِي عَلَى أَخْمَصِ قَدَمَيْهِ فَإِذَا هُوَ سَاجِدٌ يَقُولُ ‏ "‏ أَعُوذُ بِعَفْوِكَ مِنْ عِقَابِكَ وَأَعُوذُ بِرِضَاكَ مِنْ سَخَطِكَ وَأَعُوذُ بِكَ مِنْكَ ‏"‏ ‏.‏\hadithno{5534}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"I looked for the Messenger of Allah [SAW] one night in my bed, and I did not find him. I struck my hand on the head of the bed, and my hand fell on the soles of his feet. He was prostrating and saying: 'A'udhu bi 'afwika min 'iqabika, wa a'udhu bi ridaka min sakhatika, wa a'udhu bika minka (I seek refuge in Your forgiveness from Your punishment, and I seek refuge in Your pleasure from Your wrath, and I seek refuge in You from You)}}
\hadithdefcmd{nasai}{5535}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، أَنَّ مُعَاوِيَةَ بْنَ صَالِحٍ، حَدَّثَهُ وَحَدَّثَنِي أَزْهَرُ بْنُ سَعِيدٍ، - يُقَالُ لَهُ الْحَرَازِيُّ شَامِيٌّ عَزِيزُ الْحَدِيثِ - عَنْ عَاصِمِ بْنِ حُمَيْدٍ قَالَ سَأَلْتُ عَائِشَةَ بِمَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَفْتَتِحُ قِيَامَ اللَّيْلِ قَالَتْ سَأَلْتَنِي عَنْ شَىْءٍ مَا سَأَلَنِي عَنْهُ أَحَدٌ كَانَ يُكَبِّرُ عَشْرًا وَيُسَبِّحُ عَشْرًا وَيَسْتَغْفِرُ عَشْرًا وَيَقُولُ ‏ "‏ اللَّهُمَّ اغْفِرْ لِي وَاهْدِنِي وَارْزُقْنِي وَعَافِنِي ‏"‏ ‏.‏ وَيَتَعَوَّذُ مِنْ ضِيقِ الْمَقَامِ يَوْمَ الْقِيَامَةِ ‏.‏\hadithno{5535}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Asim bin Humaid said:"I asked 'Aishah with what the Messenger of Allah [SAW] would start Qiyam Al-Lail. She said: 'You have asked me about something that no one else has asked me about. He used to say Allahu Akbar ten times, and Subhan-Allah ten times, and Istaghfir-Allah ten times, and he would say, Allahummaghfirli, wahdini, warzuqni, wa'afini (O Allah, forgive me, guide me, grant me provision and give me good health,) and he would seek refuge from the difficulty of the standing on the Day of Resurrection}}
\hadithdefcmd{nasai}{5536}{أَخْبَرَنَا مُحَمَّدُ بْنُ آدَمَ، عَنْ أَبِي خَالِدٍ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عِلْمٍ لاَ يَنْفَعُ وَمِنْ قَلْبٍ لاَ يَخْشَعُ وَمِنْ نَفْسٍ لاَ تَشْبَعُ وَمِنْ دُعَاءٍ لاَ يُسْمَعُ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ سَعِيدٌ لَمْ يَسْمَعْهُ مِنْ أَبِي هُرَيْرَةَ بَلْ سَمِعَهُ مِنْ أَخِيهِ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{5536}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Sa'eed, from Abu Hurairah who said:"The Messenger of Allah [SAW] said: 'Allahumma inni a'udhu bika min 'ilmin la yanfa'u, wa min qalbin la yakhsha'u, wa min nafsin la tashba'u, wa min du'a'in la yusma' (O Allah, I seek refuge with You from knowledge that is of no benefit, a heart that is not humble, a soul that is not satisfied and a supplication that is not heard)}}
\hadithdefcmd{nasai}{5537}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ فَضَالَةَ بْنِ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا يَحْيَى، - يَعْنِي ابْنَ يَحْيَى - قَالَ أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَخِيهِ، عَبَّادِ بْنِ أَبِي سَعِيدٍ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عِلْمٍ لاَ يَنْفَعُ وَمِنْ قَلْبٍ لاَ يَخْشَعُ وَمِنْ نَفْسٍ لاَ تَشْبَعُ وَمِنْ دُعَاءٍ لاَ يُسْمَعُ ‏"‏ ‏.‏\hadithno{5537}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah said:"The Messenger of Allah [SAW] used to say: 'Allahumma inni a'udhu bika min 'ilmin la yanfa'u, wa min qalbin la yakhsha'u, wa min nafsin la tashba'u, wa min du'a'in la yusma' (O Allah, I seek refuge with You from knowledge that is of no benefit, a heart that is not humble, a soul that is not satisfied and a supplication that is not heard)}}
\hadithdefcmd{nasai}{5538}{أَخْبَرَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، عَنِ ابْنِ فُضَيْلٍ، عَنْ عَاصِمِ بْنِ سُلَيْمَانَ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، قَالَ كَانَ إِذَا قِيلَ لِزَيْدِ بْنِ أَرْقَمَ حَدِّثْنَا مَا، سَمِعْتَ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُ لاَ أُحَدِّثُكُمْ إِلاَّ مَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَدَّثَنَا بِهِ وَيَأْمُرُنَا أَنْ نَقُولَ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْعَجْزِ وَالْكَسَلِ وَالْبُخْلِ وَالْجُبْنِ وَالْهَرَمِ وَعَذَابِ الْقَبْرِ اللَّهُمَّ آتِ نَفْسِي تَقْوَاهَا وَزَكِّهَا أَنْتَ خَيْرُ مَنْ زَكَّاهَا أَنْتَ وَلِيُّهَا وَمَوْلاَهَا اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ نَفْسٍ لاَ تَشْبَعُ وَمِنْ قَلْبٍ لاَ يَخْشَعُ وَمِنْ عِلْمٍ لاَ يَنْفَعُ وَدَعْوَةٍ لاَ تُسْتَجَابُ ‏"‏ ‏.‏\hadithno{5538}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin Al-Harith said:"When it was said to Zaid bin Arqam: 'Tell us what you heard from the Messenger of Allah [SAW], he said: "I will not tell you anything but that which the Messenger of Allah [SAW] commanded us to say: 'Allahumma inni a'udhu bika min al-'ajzi wal-kasali, wal-bukhli, wal-jubni, wal-harami, wa 'adhabil-qabri. Allahumma at nafsi taqwaha, wa zakkaha anta khairu min zakkaha, anta waliyyuha wa mawlaha. Allahumma inni a'udhu bika min nafsin la tashba'u wa min qalbin la yakhsha'u wa min 'ilmin la yanfa'u wa du'a'in la yustajab (O Allah, I seek refuge in You from incapacity, laziness, miserliness, cowardice, old age, the torment of the grave. O Allah, make my soul obedient and purify it, for You are the best One to purify it, You are its Guardian and Lord. O Allah, I seek refuge in You from a soul that is not satisfied, a heart that is not humble, knowledge that is of no benefit and a supplication that is not answered)}}
\hadithdefcmd{nasai}{5539}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنِ الشَّعْبِيِّ، عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا خَرَجَ مِنْ بَيْتِهِ قَالَ ‏ "‏ بِسْمِ اللَّهِ رَبِّ أَعُوذُ بِكَ مِنْ أَنْ أَزِلَّ أَوْ أَضِلَّ أَوْ أَظْلِمَ أَوْ أُظْلَمَ أَوْ أَجْهَلَ أَوْ يُجْهَلَ عَلَىَّ ‏"‏ ‏.‏\hadithno{5539}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Umm Salamah that:When the Prophet [SAW] went out of his house, he said: "Bismillahi Rabbi. A'udhu bika min an azilla aw adilla aw azlima aw uzlama, aw ajhala aw yujhala 'alayya (In the name of Allah my Lord, I seek refuge in You from falling into error or going astray, or wronging (others) or being wronged, and from behaving or being treated in an ignorant manner}}
